//
//  IZegoRealtimeTranslationHandler.h
//  ZegoRealtimeTranslation
//
//  Created by zego on 2022/10/31.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@protocol IZegoRealtimeTranslationHandler <NSObject>
@optional
/// 当有识别出来的中间结果的文本时，通过此接口来通知
/// - Parameters:
///   - sttText: 语音识别的文本
- (void)onRecognizingText:(NSString * _Nullable)sttText;

/// 当有识别出来的最终结果的文本时，通过此接口来通知
/// - Parameters:
///   - sttText: 语音识别的文本
- (void)onRecognizedText:(NSString * _Nullable)sttText;
/// 当有识别出来的中间结果的文本翻译出结果后，通过此接口来通知
/// - Parameter translatedText: 语音识别的文本翻译后的结果文本
- (void)onRecognizingTranslatedText:(NSString *)translatedText;
/// 当有识别出来的最终文本翻译出结果后，通过此接口来通知
/// - Parameter translatedText: 语音实时识别出来的最终文本翻译后的结果文本
- (void)onRecognizedTranslatedText:(NSString *)translatedText;


/// 语音识别出来的中间结果的文本sttText, 翻译成目标语言(如:英语)的文本translatedText
/// - Parameters:
///   - sttText: 语音识别出的文本
///   - translatedText: 转成目标语言的文本
- (void)onRecognizingText:(NSString * _Nullable)sttText translatedText:(NSString * _Nullable)translatedText;

/// 语音识别出来的最终结果的文本sttText, 翻译成目标语言(如:英语)的文本translatedText
/// - Parameters:
///   - sttText: 语音识别出的文本
///   - translatedText: 转成目标语言的文本
- (void)onRecognizedText:(NSString * _Nullable)sttText translatedText:(NSString * _Nullable)translatedText;
/// 错误回调
/// - Parameter error: 错误码
- (void)onError:(int)errorCode;
@end

NS_ASSUME_NONNULL_END
