//
//  ZegoRealtimeTranslation.h
//  ZegoRealtimeTranslation
//
//  Created by zego on 2022/10/27.
//

#import <Foundation/Foundation.h>

//! Project version number for ZegoRealtimeTranslation.
FOUNDATION_EXPORT double ZegoRealtimeTranslationVersionNumber;

//! Project version string for ZegoRealtimeTranslation.
FOUNDATION_EXPORT const unsigned char ZegoRealtimeTranslationVersionString[];

// In this header, you should import all the public headers of your framework using statements like #import <ZegoRealtimeTranslation/PublicHeader.h>


#import "ZegoRealtimeTranslationDefines.h"
#import "ZegoRealtimeTranslationLanguageType.h"
#import "IZegoTranslateCallback.h"
#import "IZegoRealtimeTranslationHandler.h"

@interface ZegoRealtimeTranslation : NSObject

@property (nonatomic, assign) ZegoRTServiceProvider speechToTextService;  // 语音转文本使用的第三方供应商
@property (nonatomic, assign) ZegoRTServiceProvider textTranslationService;  // 文本翻译所使用的第三方供应商
@property (nonatomic, assign) ZegoSpeechLanguage sourceSpeechLanguage;  // 语音识别的源语言
@property (nonatomic, assign) ZegoTranslationLanguage targetTranslationLanguage;  // 文本翻译的目标语言
@property (nonatomic, assign, getter=isEnableTranslate) BOOL enableTranslate;  // 是否开启实时翻译，默认开启。YES-开启，NO-关闭
@property (nonatomic, assign, getter=isEnableIntermediaTranslate) BOOL enableIntermediaTranslate; // 是否开启中间结果翻译，默认开启。YES-开启，NO-关闭
@property (nonatomic, assign, readonly) BOOL isStartRealtimeTranslation;  // 是否已经开启了实时传译
// 语音识别的刷新频率（只支持科大讯飞）数据范围是：1-10频率逐级减弱，默认是3
@property (nonatomic, assign) int pgsFlashFreq;
// RT服务的服务器区域
@property (nonatomic, assign) ZegoRTServiceProviderRegion serviceProviderRegion;

+ (instancetype)new NS_UNAVAILABLE;
- (instancetype)init NS_UNAVAILABLE;

/// 获取实时传译实例
+ (instancetype)getInstance;

/// 初始化
/// - Parameter license: Zego提供给客户的license，封装了使用各个第三方服务的认证信息
/// 最开始时调用
- (int)init:(NSString *)license;

- (void)unInit;
/// 设置实时传译的事件的代理
- (void)setRealtimeTranslationHandler:(id<IZegoRealtimeTranslationHandler>)handler;
/// 开始语音识别/翻译功能
/// note:  init之后
- (int)startRealtimeTranslation;
/// 停止语音识别/翻译功能
/// note: startRealtimeTranslation之后调用
- (void)stopRealtimeTranslation;
/// 传输从Express得到的语音数据到ZegoRealtimeTranslation
/// - Parameter data: 从Express接口透传的语音数据
/// 在收到Express的onCapturedAudioData数据回调后透传到此接口
- (void)sendSpeechPCM:(NSData *)data;
//- (void)enableInterimSpeechToText:(BOOL)isEnable;

/// 文本翻译
/// - Parameters:
///   - text: 待翻译的文本
///   - service: 文本翻译的第三方供应商
///   - fromLanguage: 源语言
///   - toLanguage: 目标语言
///   - callback: 文本翻译结果回调
- (void)translate:(NSString *)text serviceProvider:(ZegoRTServiceProvider)serviceProvider fromLanguage:(ZegoTranslationLanguage)fromLanguage toLanguage:(ZegoTranslationLanguage)toLanguage callback:(IZegoTranslateCallback)callback;

- (void)startSpeechForAudioFile:(NSData *)audioData handler:(void(^)(BOOL isFinish))handler;
@end
