//
//  ZegoRealtimeTranslationDefines.h
//  ZegoRealtimeTranslation
//
//  Created by zego on 2023/12/5.
//

#ifndef ZegoRealtimeTranslationDefines_h
#define ZegoRealtimeTranslationDefines_h

typedef NS_ENUM(NSUInteger, ZegoRTServiceProvider) {
    ZegoRTServiceProviderIflytek = 0,       // 科大讯飞
    ZegoRTServiceProviderGoogle = 1,      // 谷歌
    ZegoRTServiceProviderLiveData = 2,    // 云上曲率
};

typedef NS_ENUM(NSUInteger, ZegoRTServiceProviderRegion) {
    ZegoRTServiceProviderRegionChineseMainland = 0,   // 中国大陆
    ZegoRTServiceProviderRegionHKMacaoTaiwan = 1,       // 中国香港澳门台湾
    ZegoRTServiceProviderRegionEastAsia = 2,      // 东亚：日本，韩国
    ZegoRTServiceProviderRegionSoutheastAsia = 3,  // 东南亚
};

typedef enum : NSUInteger {
    // 成功
    ZegoRealtimeTranslationErrorSuccess = 0,
    // 无效的 License，请联系 ZEGO 技术支持确认 License 是否正确。
    ZegoRealtimeTranslationErrorInvalidLicence = 1001,
    // License 过期。请联系 ZEGO 技术支持确认 License 是否正确。
    ZegoRealtimeTranslationErrorLicenseExpired = 1002,
    // 无效的包名。请联系 ZEGO 技术支持确认应用的包名是否跟 License 对应。
    ZegoRealtimeTranslationErrorInvalidPackageName = 1003,
    // 已经启动了语音识别。根据需要处理。
    ZegoRealtimeTranslationErrorAlreadyStarted = 1004,
    // 对应依赖没有引入到项目。没有引入 Google 或微软的包。
    ZegoRealtimeTranslationErrorClassNotFound = 1005,
    // 语音识别的语言不支持。重新设置正确的识别语言。
    ZegoRealtimeTranslationErrorSpeechLanguageNotSuport = 1006,
    // 没有网络。检查网络是否正常。
    ZegoRealtimeTranslationErrorNoNetwork = 1007,
    // 网络问题网络错误。检查网络是否正常。
    ZegoRealtimeTranslationErrorNetworkError = 1008,
    // 请求超时。检查网络是否正常。
    ZegoRealtimeTranslationErrorRequestTimeout = 1009,
    // 无效的账号。请联系 ZEGO 技术支持确认 License 是否正确。
    ZegoRealtimeTranslationErrorInvalidAccount = 1010,
    // 已超出使用量。请联系 ZEGO 技术支持确认使用情况。
    ZegoRealtimeTranslationErrorQuotaExceeded = 1011,
    // 未知错误。请联系 ZEGO 技术支持进行处理。
    ZegoRealtimeTranslationErrorUnkownError = 1012,
    // 翻译源与目标设置错误 （比如：一样）。检查参数是否正确。
    ZegoRealtimeTranslationErrorBadLanguagePair = 1013,
    // 错误的请求。检查参数是否正确。
    ZegoRealtimeTranslationErrorWrongRequest = 1014,
    // 文本翻译出错，可能是需要翻译的文本过长，最好限制在1300个字符以内。检查参数是否正确。
    ZegoRealtimeTranslationErrorWrongTranslateRequest = 1015,
    // 翻译的语言不支持（可能是没有授权）。请联系 ZEGO 技术支持确认使用情况。
    ZegoRealtimeTranslationErrorTranslateServiceLicenseFailed = 1016,
    // 语音识别的服务未授权或已过期。请联系 ZEGO 技术支持确认使用情况。
    ZegoRealtimeTranslationErrorSpeechToTextServiceLicenseFailed = 1017,
    // 不支持所设置的语言互译
    ZegoRealtimeTranslationErrorSourceLanguageCannotTranslateToTargetLanguage = 1018,
    // 文本翻译语言参数设置错误
//    ZegoRealtimeTranslationErrorTranslateParmterError = 1019,
//    ZegoRealtimeTranslationErrorParamValidate = 1020,
    ZegoRealtimeTranslationErrorStreamIDNotExist = 1019,
} ZegoRealtimeTranslationError;

typedef enum : NSUInteger {
    // 南非荷兰语
    ZegoSpeechLanguageAF_ZA = 0,
    // 阿姆哈拉语(埃塞俄比亚)
    ZegoSpeechLanguageAM_ET,
    // 阿拉伯语（阿拉伯联合酋长国)
    ZegoSpeechLanguageAR_AE,
    // 阿拉伯语（巴林）
    ZegoSpeechLanguageAR_BH,
    // 阿拉伯语（阿尔及利亚）
    ZegoSpeechLanguageAR_DZ,
    // 阿拉伯语（埃及）
    ZegoSpeechLanguageAR_EG,
    // 阿拉伯语（以色列）
    ZegoSpeechLanguageAR_IL,
    // 阿拉伯语（伊拉克）
    ZegoSpeechLanguageAR_IQ,
    // 阿拉伯语（约旦）
    ZegoSpeechLanguageAR_JO,
    // 阿拉伯语（科威特）
    ZegoSpeechLanguageAR_KW,
    // 阿拉伯语（黎巴嫩）
    ZegoSpeechLanguageAR_LB,
    // 阿拉伯语（利比亚）
    ZegoSpeechLanguageAR_LY,
    // 阿拉伯语（摩洛哥）
    ZegoSpeechLanguageAR_MA,
    // 阿拉伯语（阿曼）
    ZegoSpeechLanguageAR_OM,
    // 阿拉伯语(巴勒斯坦占领区)
    ZegoSpeechLanguageAR_PS,
    // 阿拉伯语（卡塔尔）
    ZegoSpeechLanguageAR_QA,
    // 阿拉伯语(沙特阿拉伯)
    ZegoSpeechLanguageAR_SA,
    // 阿拉伯语（叙利亚）
    ZegoSpeechLanguageAR_SY,
    // 阿拉伯语（突尼斯）
    ZegoSpeechLanguageAR_TN,
    // 阿拉伯语（也门）
    ZegoSpeechLanguageAR_YE,
    // 阿塞拜疆语（阿塞拜疆）
    ZegoSpeechLanguageAZ_AZ,
    // 保加利亚语(保加利亚)
    ZegoSpeechLanguageBG_BG,
    // 孟加拉语（孟加拉国）
    ZegoSpeechLanguageBN_BD,
    //孟加拉语（印度）
    ZegoSpeechLanguageBN_IN,
    // 波斯尼亚语(波斯尼亚)
    ZegoSpeechLanguageBS_BA,
    // 加泰罗尼亚语(西班牙)
    ZegoSpeechLanguageCA_ES,
    // 捷克语（捷克）
    ZegoSpeechLanguageCS_CZ,
    // 威尔士语（英国）
    ZegoSpeechLanguageCY_GB,
    // 丹麦语（丹麦）
    ZegoSpeechLanguageDA_DK,
    // 德语（奥地利）
    ZegoSpeechLanguageDE_AT,
    // 德语（瑞士）
    ZegoSpeechLanguageDE_CH,
    // 德语（德国）
    ZegoSpeechLanguageDE_DE,
    // 希腊语(希腊)
    ZegoSpeechLanguageEL_GR,
    // 英语（澳大利亚）
    ZegoSpeechLanguageEN_AU,
    // 英语（加拿大）
    ZegoSpeechLanguageEN_CA,
    // 英语（英国）
    ZegoSpeechLanguageEN_GB,
    // 英语（加纳）
    ZegoSpeechLanguageEN_GH,
    // 英语（香港特别行政区）
    ZegoSpeechLanguageEN_HK,
    // 英语（爱尔兰）
    ZegoSpeechLanguageEN_IE,
    // 英语（印度）
    ZegoSpeechLanguageEN_IN,
    // 英语（肯尼亚）
    ZegoSpeechLanguageEN_KE,
    // 英语（尼日利亚）
    ZegoSpeechLanguageEN_NG,
    // 英语（新西兰）
    ZegoSpeechLanguageEN_NZ,
    // 英语（菲律宾）
    ZegoSpeechLanguageEN_PH,
    // 英语（新加坡）
    ZegoSpeechLanguageEN_SG,
    // 英语（坦桑尼亚）
    ZegoSpeechLanguageEN_TZ,
    // 英语（美国）
    ZegoSpeechLanguageEN_US,
    // 英语（南非）
    ZegoSpeechLanguageEN_ZA,
    // 西班牙语（阿根廷）
    ZegoSpeechLanguageES_AR,
    // 西班牙语（玻利维亚）
    ZegoSpeechLanguageES_BO,
    // 西班牙语（智利）
    ZegoSpeechLanguageES_CL,
    // 西班牙语（哥伦比亚）
    ZegoSpeechLanguageES_CO,
    // 西班牙语（哥斯达黎加）
    ZegoSpeechLanguageES_CR,
    // 西班牙语（古巴）
    ZegoSpeechLanguageES_CU,
    // 西班牙语（多米尼加共和国）
    ZegoSpeechLanguageES_DO,
    // 西班牙语（厄瓜多尔）
    ZegoSpeechLanguageES_EC,
    // 西班牙语 (西班牙)
    ZegoSpeechLanguageES_ES,
    // 西班牙语（赤道几内亚）
    ZegoSpeechLanguageES_GQ,
    // 西班牙语（危地马拉）
    ZegoSpeechLanguageES_GT,
    // 西班牙语（洪都拉斯）
    ZegoSpeechLanguageES_HN,
    // 西班牙语（墨西哥）
    ZegoSpeechLanguageES_MX,
    // 西班牙（尼加拉瓜）
    ZegoSpeechLanguageES_NI,
    // 西班牙语（巴拿马）
    ZegoSpeechLanguageES_PA,
    // 西班牙语（秘鲁）
    ZegoSpeechLanguageES_PE,
    // 西班牙语（波多黎各）
    ZegoSpeechLanguageES_PR,
    // 西班牙语（巴拉圭）
    ZegoSpeechLanguageES_PY,
    // 西班牙语（萨尔瓦多）
    ZegoSpeechLanguageES_SV,
    // 西班牙语（美国）
    ZegoSpeechLanguageES_US,
    // 西班牙语（乌拉圭）
    ZegoSpeechLanguageES_UY,
    // 西班牙语（委内瑞拉）
    ZegoSpeechLanguageES_VE,
    // 爱沙尼亚语(爱沙尼亚)
    ZegoSpeechLanguageET_EE,
    // 巴斯克语
    ZegoSpeechLanguageEU_ES,
    // 波斯语（伊朗）
    ZegoSpeechLanguageFA_IR,
    // 芬兰语（芬兰）
    ZegoSpeechLanguageFI_FI,
    // 菲律宾语（菲律宾）
    ZegoSpeechLanguageFIL_PH,
    // 法语（比利时）
    ZegoSpeechLanguageFR_BE,
    // 法语（加拿大）
    ZegoSpeechLanguageFR_CA,
    // 法语（瑞士）
    ZegoSpeechLanguageFR_CH,
    // 法语（法国）
    ZegoSpeechLanguageFR_FR,
    // 爱尔兰语（爱尔兰）
    ZegoSpeechLanguageGA_IE,
    // 加利西亚语
    ZegoSpeechLanguageGL_ES,
    // 古吉拉特语（印度）
    ZegoSpeechLanguageGU_IN,
    // 希伯来语（以色列）
    ZegoSpeechLanguageHE_IL,
    // 印地语（印度）
    ZegoSpeechLanguageHI_IN,
    // 克罗地亚语（克罗地亚）
    ZegoSpeechLanguageHR_HR,
    // 匈牙利语(匈牙利)
    ZegoSpeechLanguageHU_HU,
    // 亚美尼亚语（亚美尼亚）
    ZegoSpeechLanguageHY_AM,
    // 印度尼西亚语(印度尼西亚)
    ZegoSpeechLanguageID_ID,
    // 冰岛语(冰岛)
    ZegoSpeechLanguageIS_IS,
    // 意大利语（瑞士）
    ZegoSpeechLanguageIT_CH,
    // 意大利语（意大利）
    ZegoSpeechLanguageIT_IT,
    // 日语（日本）
    ZegoSpeechLanguageJA_JP,
    // 爪哇语（印度尼西亚）
    ZegoSpeechLanguageJV_ID,
    // 格鲁吉亚语（格鲁吉亚）
    ZegoSpeechLanguageKA_GE,
    // 哈萨克语（哈萨克斯坦）
    ZegoSpeechLanguageKK_KZ,
    // 高棉语(柬埔寨)
    ZegoSpeechLanguageKM_KH,
    // 卡纳达语（印度）
    ZegoSpeechLanguageKN_IN,
    // 韩语(韩国)
    ZegoSpeechLanguageKO_KR,
    // 老挝语(老挝)
    ZegoSpeechLanguageLO_LA,
    // 立陶宛语(立陶宛)
    ZegoSpeechLanguageLT_LT,
    // 拉脱维亚语(拉脱维亚)
    ZegoSpeechLanguageLV_LV,
    // 马其顿语（北马其顿共和国
    ZegoSpeechLanguageMK_MK,
    // 马拉雅拉姆语（印度）
    ZegoSpeechLanguageML_IN,
    // 蒙古语（蒙古）
    ZegoSpeechLanguageMN_MN,
    // 马拉地语（印度）
    ZegoSpeechLanguageMR_IN,
    // 马来语（马来西亚）
    ZegoSpeechLanguageMS_MY,
    // 马耳他语（马耳他）
    ZegoSpeechLanguageMT_MT,
    // 缅甸语(缅甸)
    ZegoSpeechLanguageMY_MM,
    // 挪威语（博克马尔语，挪威)
    ZegoSpeechLanguageNB_NO,
    // 尼泊尔语（尼泊尔）
    ZegoSpeechLanguageNE_NP,
    // 荷兰语（比利时）
    ZegoSpeechLanguageNL_BE,
    // 荷兰语（荷兰）
    ZegoSpeechLanguageNL_NL,
    // 波兰语（波兰）
    ZegoSpeechLanguagePL_PL,
    // 普什图语（阿富汗）
    ZegoSpeechLanguagePS_AF,
    // 葡萄牙语（巴西）
    ZegoSpeechLanguagePT_BR,
    // 葡萄牙语(葡萄牙)
    ZegoSpeechLanguagePT_PT,
    // 罗马尼亚语（罗马尼亚）
    ZegoSpeechLanguageRO_RO,
    // 俄语（俄罗斯）
    ZegoSpeechLanguageRU_RU,
    // 僧伽罗语(斯里兰卡)
    ZegoSpeechLanguageSI_LK,
    // 斯洛伐克语（斯洛伐克）
    ZegoSpeechLanguageSK_SK,
    // 斯洛文尼亚语(斯洛文尼亚)
    ZegoSpeechLanguageSL_SI,
    // 索马里语（索马里）
    ZegoSpeechLanguageSO_SO,
    // 阿尔巴尼亚语（阿尔巴尼亚）
    ZegoSpeechLanguageSQ_AL,
    // 塞尔维亚语（塞尔维亚）
    ZegoSpeechLanguageSR_RS,
    // 巽他语（印度尼西亚）
    ZegoSpeechLanguageSU_ID,
    // 瑞典语（瑞典）
    ZegoSpeechLanguageSV_SE,
    // 斯瓦希里语(肯尼亚)
    ZegoSpeechLanguageSW_KE,
    // 斯瓦希里语（坦桑尼亚）
    ZegoSpeechLanguageSW_TZ,
    // 泰米尔语（印度）
    ZegoSpeechLanguageTA_IN,
    // 泰米尔语（斯里兰卡）
    ZegoSpeechLanguageTA_LK,
    // 泰米尔语（马来西亚）
    ZegoSpeechLanguageTA_MY,
    // 泰米尔语（新加坡）
    ZegoSpeechLanguageTA_SG,
    // 泰卢固语（印度）
    ZegoSpeechLanguageTE_IN,
    // 泰语（泰国）
    ZegoSpeechLanguageTH_TH,
    // 土耳其语（土耳其)
    ZegoSpeechLanguageTR_TR,
    // 乌克兰语(乌克兰)
    ZegoSpeechLanguageUK_UA,
    // 乌尔都语(印度)
    ZegoSpeechLanguageUR_IN,
    // 乌尔都语（巴基斯坦）
    ZegoSpeechLanguageUR_PK,
    // 乌兹别克语（乌兹别克斯坦）
    ZegoSpeechLanguageUZ_UZ,
    // 越南语(越南)
    ZegoSpeechLanguageVI_VN,
    // 吴语(中国)
    ZegoSpeechLanguageWUU_CN,
    // 粤语(中国)
    ZegoSpeechLanguageYUE_CN,
    // 中文（普通话，简体）
    ZegoSpeechLanguageZH_CN,
    // 中文(中原官话河南，简体)河南口音
    ZegoSpeechLanguageZH_CN_HENAN,
    // 中文(东北官话，简体)辽宁口音
    ZegoSpeechLanguageZH_CN_LIAONING,
    // 中文(中原官话陕西，简体)陕西口音
    ZegoSpeechLanguageZH_CN_SHAANXI,
    // 中文(冀鲁官话，简体)山东口音
    ZegoSpeechLanguageZH_CN_SHANDONG,
    // 中文（西南普通话，简体）
    ZegoSpeechLanguageZH_CN_SICHUAN,
    // 中文（粤语，繁体）
    ZegoSpeechLanguageZH_HK,
    // 中文(台湾普通话)
    ZegoSpeechLanguageZH_TW,
    // 祖鲁语（南非）
    ZegoSpeechLanguageZU_ZA,
    
} ZegoSpeechLanguage;

typedef enum : NSUInteger {
    // 南非荷兰语
    ZegoTranslationLanguageAF,
    // 阿姆哈拉语
    ZegoTranslationLanguageAM,
    // 阿拉伯语
    ZegoTranslationLanguageAR,
    // 阿萨姆语
    ZegoTranslationLanguageAS,
    // 阿塞拜疆语(拉丁语)
    ZegoTranslationLanguageAZ,
    // 巴什基尔语
    ZegoTranslationLanguageBA,
    // 白俄罗斯语
    ZegoTranslationLanguageBE,
    // 别姆巴语
    ZegoTranslationLanguageBEM,
    // 保加利亚语
    ZegoTranslationLanguageBG,
    // 比斯拉马语
    ZegoTranslationLanguageBI,
    // Bangla
    ZegoTranslationLanguageBN,
    // 藏语
    ZegoTranslationLanguageBO,
    // 波斯尼亚语(拉丁语系)
    ZegoTranslationLanguageBS,
    // 加泰罗尼亚语
    ZegoTranslationLanguageCA,
    // 宿务语
    ZegoTranslationLanguageCEB,
    // 科西嘉语
    ZegoTranslationLanguageCO,
    // 塞舌尔克里奥尔语
    ZegoTranslationLanguageCRS,
    // 捷克语
    ZegoTranslationLanguageCS,
    // 威尔士语
    ZegoTranslationLanguageCY,
    // 丹麦语
    ZegoTranslationLanguageDA,
    // 德语
    ZegoTranslationLanguageDE,
    // 埃维语
    ZegoTranslationLanguageEE,
    // 马尔代夫语
    ZegoTranslationLanguageDV,
    // 希腊语
    ZegoTranslationLanguageEL,
    // 英语
    ZegoTranslationLanguageEN,
    // 世界语
    ZegoTranslationLanguageEO,
    // 西班牙语
    ZegoTranslationLanguageES,
    // 爱沙尼亚语
    ZegoTranslationLanguageET,
    // 巴斯克语
    ZegoTranslationLanguageEU,
    // 波斯语
    ZegoTranslationLanguageFA,
    // 芬兰语
    ZegoTranslationLanguageFI,
    // 菲律宾语
    ZegoTranslationLanguageFIL,
    // 斐济语
    ZegoTranslationLanguageFJ,
    // 法罗语
    ZegoTranslationLanguageFO,
    // 法语
    ZegoTranslationLanguageFR,
    // 法语(加拿大)
    ZegoTranslationLanguageFR_CA,
    // 弗里西语
    ZegoTranslationLanguageFY,
    // 爱尔兰语
    ZegoTranslationLanguageGA,
    // 苏格兰盖尔语
    ZegoTranslationLanguageGD,
    // 加利西亚语
    ZegoTranslationLanguageGL,
    // 古吉拉特语
    ZegoTranslationLanguageGU,
    // 豪萨语
    ZegoTranslationLanguageHA,
    // 夏威夷语
    ZegoTranslationLanguageHAW,
    // 希伯来语
    ZegoTranslationLanguageHE,
    // Hindi
    ZegoTranslationLanguageHI,
    // 克罗地亚语
    ZegoTranslationLanguageHR,
    // 上索布语
    ZegoTranslationLanguageHSB,
    // 海地克里奥尔语
    ZegoTranslationLanguageHT,
    // 匈牙利语
    ZegoTranslationLanguageHU,
    // 亚美尼亚语
    ZegoTranslationLanguageHY,
    // 印度尼西亚语
    ZegoTranslationLanguageID,
    // 伊博语
    ZegoTranslationLanguageIG,
    // 因纽纳敦语
    ZegoTranslationLanguageIKT,
    // 冰岛语
    ZegoTranslationLanguageIS,
    // 意大利语
    ZegoTranslationLanguageIT,
    // 因纽特语
    ZegoTranslationLanguageIU,
    // 因纽特语(拉丁语)
    ZegoTranslationLanguageIU_LATN,
    // 日语
    ZegoTranslationLanguageJA,
    // 印尼爪哇语
    ZegoTranslationLanguageJV,
    // 格鲁吉亚语
    ZegoTranslationLanguageKA,
    // 凯克其语
    ZegoTranslationLanguageKEK,
    // 刚果语
    ZegoTranslationLanguageKG,
    // 哈萨克语
    ZegoTranslationLanguageKK,
    // 高棉语
    ZegoTranslationLanguageKM,
    // 库尔德语(北部)
    ZegoTranslationLanguageKMR,
    // 卡纳达语
    ZegoTranslationLanguageKN,
    // 韩语
    ZegoTranslationLanguageKO,
    // 库尔德语(中部)
    ZegoTranslationLanguageKU,
    // 吉尔吉斯语(西里尔语)
    ZegoTranslationLanguageKY,
    // 拉丁语
    ZegoTranslationLanguageLA,
    // 卢森堡语
    ZegoTranslationLanguageLB,
    // 卢干达语
    ZegoTranslationLanguageLG,
    // 林加拉语
    ZegoTranslationLanguageLN,
    // 老挝语
    ZegoTranslationLanguageLO,
    // 立陶宛语
    ZegoTranslationLanguageLT,
    // 拉脱维亚语
    ZegoTranslationLanguageLV,
    // 中文(文学)
    ZegoTranslationLanguageLZH,
    // 马达加斯加语
    ZegoTranslationLanguageMG,
    // 马里语
    ZegoTranslationLanguageMHR,
    // 毛利语
    ZegoTranslationLanguageMI,
    // 马其顿语
    ZegoTranslationLanguageMK,
    // 马拉雅拉姆语
    ZegoTranslationLanguageML,
    // 蒙古语(西里尔文)
    ZegoTranslationLanguageMN_CYRL,
    // 蒙古语(传统)
    ZegoTranslationLanguageMN_MONG,
    // 马拉地语
    ZegoTranslationLanguageMR,
    // 山地马里语
    ZegoTranslationLanguageMRJ,
    // 马来语(拉丁语系)
    ZegoTranslationLanguageMS,
    // 马耳他语
    ZegoTranslationLanguageMT,
    // 白苗语(拉丁语)
    ZegoTranslationLanguageMWW,
    // 缅甸
    ZegoTranslationLanguageMY,
    // 博克马尔语
    ZegoTranslationLanguageNB,
    // 尼泊尔语
    ZegoTranslationLanguageNE,
    // 荷兰语
    ZegoTranslationLanguageNL,
    // 挪威语
    ZegoTranslationLanguageNO,
    // 齐切瓦语
    ZegoTranslationLanguageNY,
    // 奥罗莫语
    ZegoTranslationLanguageOM,
    // 奥里亚语
    ZegoTranslationLanguageOR,
    // 奥赛梯语
    ZegoTranslationLanguageOS,
    // 克雷塔罗奥托米语
    ZegoTranslationLanguageOTQ,
    // 旁遮普语
    ZegoTranslationLanguagePA,
    // 帕皮阿门托语
    ZegoTranslationLanguagePAP,
    // 波兰语
    ZegoTranslationLanguagePL,
    // 达里语
    ZegoTranslationLanguagePRS,
    // 普什图语
    ZegoTranslationLanguagePS,
    // 葡萄牙语(巴西)
    ZegoTranslationLanguagePT,
    // 葡萄牙语(葡萄牙)
    ZegoTranslationLanguagePT_PT,
    // 隆迪语
    ZegoTranslationLanguageRN,
    // 罗马尼亚语
    ZegoTranslationLanguageRO,
    // 俄语
    ZegoTranslationLanguageRU,
    // 卢旺达语
    ZegoTranslationLanguageRW,
    // 信德语
    ZegoTranslationLanguageSD,
    // 桑戈语
    ZegoTranslationLanguageSG,
    // 僧伽罗语
    ZegoTranslationLanguageSI,
    // 斯洛伐克语
    ZegoTranslationLanguageSK,
    // 斯洛文尼亚语
    ZegoTranslationLanguageSL,
    // 萨摩亚语(拉丁语)
    ZegoTranslationLanguageSM,
    // 修纳语
    ZegoTranslationLanguageSN,
    // 索马里语(阿拉伯语)
    ZegoTranslationLanguageSO,
    // 阿尔巴尼亚语
    ZegoTranslationLanguageSQ,
    // 塞尔维亚语(西里尔)
    ZegoTranslationLanguageSR_CYRL,
    // 塞尔维亚语(拉丁)
    ZegoTranslationLanguageSR_LATN,
    // 塞索托语
    ZegoTranslationLanguageST,
    // 印尼巽他语
    ZegoTranslationLanguageSU,
    // 瑞典语
    ZegoTranslationLanguageSV,
    // 斯瓦希里语(拉丁语)
    ZegoTranslationLanguageSW,
    // 泰米尔语
    ZegoTranslationLanguageTA,
    // 泰卢固语
    ZegoTranslationLanguageTE,
    // 塔吉克语
    ZegoTranslationLanguageTG,
    // 茨瓦纳语
    ZegoTranslationLanguageTN,
    // 泰语
    ZegoTranslationLanguageTH,
    // 提格里尼亚语
    ZegoTranslationLanguageTI,
    // 提格雷语
    ZegoTranslationLanguageTIG,
    // 土库曼语(拉丁语)
    ZegoTranslationLanguageTK,
    // 克林贡语
    ZegoTranslationLanguageTLH_LATN,
    // 克林贡语(plqaD)
    ZegoTranslationLanguageTLH_PIQD,
    // 汤加语
    ZegoTranslationLanguageTO,
    // 巴布亚皮钦语
    ZegoTranslationLanguageTPI,
    // 土耳其语
    ZegoTranslationLanguageTR,
    // 聪加语
    ZegoTranslationLanguageTS,
    // 鞑靼语(拉丁语)
    ZegoTranslationLanguageTT,
    // 契维语
    ZegoTranslationLanguageTW,
    // 塔希提语
    ZegoTranslationLanguageTY,
    // 乌德穆尔特语
    ZegoTranslationLanguageUDM,
    // 维吾尔语(阿拉伯语)
    ZegoTranslationLanguageUG,
    // 乌克兰语
    ZegoTranslationLanguageUK,
    // 乌尔都语
    ZegoTranslationLanguageUR,
    // 乌兹别克语(拉丁语)
    ZegoTranslationLanguageUZ,
    // 越南语
    ZegoTranslationLanguageVI,
    // 瓦瑞语
    ZegoTranslationLanguageWAR,
    // 南非科萨语
    ZegoTranslationLanguageXH,
    // 意第绪语
    ZegoTranslationLanguageYI,
    // 约鲁巴语
    ZegoTranslationLanguageYO,
    // 尤卡坦玛雅语
    ZegoTranslationLanguageYUA,
    // 粤语(繁体)
    ZegoTranslationLanguageYUE,
    // 简体中文
    ZegoTranslationLanguageZH_HANS,
    // 中文(繁体)
    ZegoTranslationLanguageZH_HANT,
    // 祖鲁语
    ZegoTranslationLanguageZU,
} ZegoTranslationLanguage;

#endif /* ZegoRealtimeTranslationDefines_h */
