//
//  ViewController.m
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/10/26.
//

#import "ViewController.h"
#import <Masonry/Masonry.h>
#import "ZegoRoomViewController.h"
#import "ZegoGlobalDefines.h"
#import "RTCEngineManager.h"
#import "SPAlertController+ActionSheet.h"
#import "ZegoRoleSelectCustomView.h"
#import "ZegoHudManager.h"

@interface ViewController ()
@property (nonatomic, strong) NSMutableArray *dataSource;
@property (nonatomic, strong) NSArray<NSString *> *randomNames;
@property (nonatomic, copy) NSString *roomId;
@property (nonatomic, strong) RTCEngineManager *rtcManger;

@end

@implementation ViewController

static NSString * const TAG = @"MainViewController";

- (NSArray<NSString *> *)randomNames {
    if (!_randomNames) {
        _randomNames = @[@"张三", @"李四", @"王五", @"武则天", @"秦始皇", @"刘邦", @"项羽", @"女娲", @"王昭君", @"西施",@"貂蝉", @"杨玉环", @"赵飞燕", @"上官婉儿", @"孙悟空", @"唐僧", @"猪八戒", @"牛魔王", @"盘古", @"太上老君", @"周瑜", @"吴刚"];
    }
    return _randomNames;
}

- (NSMutableArray *)dataSource {
    if (!_dataSource) {
        _dataSource = [NSMutableArray new];
        for (NSInteger i = 1; i <= 10; i++) {
            [_dataSource addObject:[NSString stringWithFormat:@"房间%02ld", i]];
        }
    }
    return _dataSource;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    
    self.title = @"房间列表";
    
    [self setupUI];
    self.rtcManger = [RTCEngineManager sharedManager];
    [self.rtcManger initRtc];
}

- (void)setupUI {
    NSDictionary *infoDictionary = [[NSBundle mainBundle] infoDictionary];
    // app版本
    NSString *app_Version = [infoDictionary objectForKey:@"CFBundleShortVersionString"];
    // app build版本
    NSString *app_build = [infoDictionary objectForKey:@"CFBundleVersion"];
    UILabel *versionLabel = [[UILabel alloc] init];
    versionLabel.text = [NSString stringWithFormat:@"版本：%@(%@)", app_Version, app_build];
    versionLabel.textColor = LCColor(51, 51, 51);
    versionLabel.font = [UIFont systemFontOfSize:13];
    [self.view addSubview:versionLabel];
    
    [versionLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.mas_equalTo(10);
        make.top.mas_equalTo(ZEGO_IPHONE_NAVIGATIONBAR_HEIGHT+12);
    }];
    
    CGFloat ySpace = 15;
    NSInteger rows = 5;
    NSInteger colums = 2;
    CGFloat btnWidth = (kScreenWidth - 2*10 - ySpace)/colums;
    CGFloat btnHeight = (SCREEN_SIZE.height - 10 - ZEGO_IPHONE_NAVIGATIONBAR_HEIGHT - 30 - 15*(rows-1)) / rows;
    for (NSInteger i = 0; i < self.dataSource.count; i++) {
        UIButton *button = [[UIButton alloc] initWithFrame:CGRectZero];
        button.backgroundColor = [UIColor blueColor];
        button.layer.cornerRadius = 8.0f;
        button.layer.masksToBounds = YES;
        [button setTitle:self.dataSource[i] forState:UIControlStateNormal];
        [button setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
        button.tag = i+1;
        [button addTarget:self action:@selector(buttonClicked:) forControlEvents:UIControlEventTouchUpInside];
        [self.view addSubview:button];

        [button mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(10 + i%2*(btnWidth+15));
            make.top.mas_equalTo(ZEGO_IPHONE_NAVIGATIONBAR_HEIGHT + 30 + i/2*(btnHeight+15));
            make.width.mas_equalTo(btnWidth);
            make.height.mas_equalTo(btnHeight);
        }];
    }
}

- (void)buttonClicked:(UIButton *)sender {
    NSInteger tag = sender.tag;
    NSLog(@"click tag: %ld", tag);
    
    __block BOOL isEnterRoom = NO;
    // 用户昵称
    int index = arc4random() % self.randomNames.count;
    NSString *username = [self.randomNames objectAtIndex:index];
    
    ZegoRoleSelectCustomView *customView = [[ZegoRoleSelectCustomView alloc] initWithFrame:CGRectMake(0, 0, SCREEN_SIZE.width - 60, 220)];
    customView.username = username;
    customView.backgroundColor = [UIColor whiteColor];
    SPAlertController *alertController = [SPAlertController alertControllerWithCustomAlertView:customView preferredStyle:SPAlertControllerStyleAlert animationType:SPAlertAnimationTypeExpand];
    
    __weak typeof(self) weakSelf = self;
    __weak typeof(customView) weakRoleView = customView;
    __block NSInteger role = 0;
    customView.selectRoleBlock = ^{
        NSArray<NSString *> *btnTitles = @[@"主播", @"观众"];
        SPAlertController *alertVc = [SPAlertController alertControllerWithTitle:@"" buttonTitles:btnTitles redButtonIndex:-1 actionHandler:^(NSInteger buttonIndex) {
            weakRoleView.roleName = [btnTitles objectAtIndex:buttonIndex];
            role = buttonIndex;
        }];
        [alertController presentViewController:alertVc animated:YES completion:nil];
    };
    
    customView.enterRoomBlock = ^(NSString * _Nonnull nickname) {
        if (nickname.length <= 0) {
            [ZegoHudManager showMessage:@"用户名不能为空"];
            return;
        }
        
        if (isEnterRoom) {
            return;
        }
        
        isEnterRoom = YES;
        
        BOOL isHost = role == 0;
        
        NSString *userID = [NSString stringWithFormat:@"%.0f", [[NSDate date] timeIntervalSince1970]];
        
        NSString *newRoomID = @(tag).stringValue;
        if (![newRoomID isEqualToString:weakSelf.roomId] || !weakSelf.rtcManger.isInRoom) {
            [weakSelf.rtcManger logoutRoom];
            weakSelf.roomId = newRoomID;
            NSString *finalUserID = userID;
            [weakSelf.rtcManger loginRoom:weakSelf.roomId roomName:weakSelf.roomId userID:userID userName:nickname callback:^(int errorCode, NSDictionary * _Nonnull extendedData) {
                if (errorCode == 0) {
                    NSLog(@"%@ login %@ success", TAG, weakSelf.roomId);
                    ZegoRoomUser *roomUser = [[ZegoRoomUser alloc] initWithRoomID:newRoomID roomName:newRoomID userID:finalUserID userName:nickname isHost:isHost];
                    [weakSelf jumpToRoomVc:roomUser];
                } else {
                    NSLog(@"%@ login failed, errorCode: %d", TAG, errorCode);
                    [ZegoHudManager showMessage:[NSString stringWithFormat:@"login %@ failed: %d", weakSelf.roomId, errorCode]];
                }
            }];
        } else {
            ZegoRoomUser *roomUser = [[ZegoRoomUser alloc] initWithRoomID:weakSelf.roomId roomName:weakSelf.roomId userID:userID userName:nickname isHost:isHost];
            [weakSelf jumpToRoomVc:roomUser];
        }
    };
    [self presentViewController:alertController animated:YES completion:nil];
}

- (void)jumpToRoomVc:(ZegoRoomUser *)roomUser {
    [self dismissViewControllerAnimated:YES completion:nil];
    ZegoRoomViewController *roomVc = [ZegoRoomViewController new];
    roomVc.roomUser = roomUser;
    [self.navigationController pushViewController:roomVc animated:YES];
}

@end
