//
//  ZegoAudioCaptureViewController.m
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/11/26.
//

#import "ZegoAudioCaptureViewController.h"
#import <Masonry/Masonry.h>
#import "ZegoGlobalDefines.h"
#import <AVFoundation/AVFoundation.h>
#import "ZegoAudioCapture.h"
#import "SPAlertController+ActionSheet.h"
#import <ZegoRealtimeTranslation/ZegoRealtimeTranslation.h>

@interface ZegoAudioCaptureViewController ()<UIDocumentInteractionControllerDelegate>
@property (nonatomic, strong) UITextField *fileNameTextField;
@property (nonatomic, strong) UIButton *captureBtn;
@property (nonatomic, assign) BOOL isStart;
@property (nonatomic, strong) ZegoAudioConfig *audioConfig;
@property (nonatomic, strong) ZegoAudioCapture *audioCapture;
@property (nonatomic, strong) NSFileHandle *fileHandle;
@property (nonatomic, copy) NSString *audioFileName;
@end

@implementation ZegoAudioCaptureViewController

- (UITextField *)fileNameTextField {
    if (!_fileNameTextField) {
        _fileNameTextField = [[UITextField alloc] init];
        _fileNameTextField.text = @"test";
        _fileNameTextField.textColor = LCColor(51, 51, 51);
        _fileNameTextField.font = [UIFont systemFontOfSize:14];
        _fileNameTextField.layer.cornerRadius = 4.0f;
        _fileNameTextField.clipsToBounds = YES;
        _fileNameTextField.layer.borderColor = LCColor(51, 51, 51).CGColor;
        _fileNameTextField.layer.borderWidth = 1.0;
        _fileNameTextField.leftView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, 15, 30)];
        _fileNameTextField.leftViewMode = UITextFieldViewModeAlways;
    }
    return _fileNameTextField;
}

- (UIButton *)captureBtn {
    if (!_captureBtn) {
        _captureBtn = [[UIButton alloc] init];
        [_captureBtn setTitle:@"开始采集" forState:UIControlStateNormal];
        [_captureBtn setTitle:@"停止采集" forState:UIControlStateSelected];
        [_captureBtn setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
        [_captureBtn setTitleColor:[UIColor whiteColor] forState:UIControlStateSelected];
        _captureBtn.backgroundColor = [UIColor blueColor];
        _captureBtn.titleLabel.font = [UIFont systemFontOfSize:14.0f];
        _captureBtn.layer.cornerRadius = 4.0f;
        _captureBtn.clipsToBounds = YES;
        [_captureBtn addTarget:self action:@selector(captureBtnClicked:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _captureBtn;
}

- (ZegoAudioConfig *)audioConfig {
    if (!_audioConfig) {
        _audioConfig = [ZegoAudioConfig defaultConfig];
    }
    
    return _audioConfig;
}

- (ZegoAudioCapture *)audioCapture {
    if (!_audioCapture) {
        __weak typeof(self) weakSelf = self;
        _audioCapture = [[ZegoAudioCapture alloc] initWithConfig:self.audioConfig];
        _audioCapture.errorCallBack = ^(NSError* error) {
            NSLog(@"KFAudioCapture error: %zi %@", error.code, error.localizedDescription);
        };
        // 音频采集数据回调。在这里将 PCM 数据写入文件。
        _audioCapture.sampleBufferOutputCallBack = ^(CMSampleBufferRef sampleBuffer) {
            if (sampleBuffer) {
                // 1、获取 CMBlockBuffer，这里面封装着 PCM 数据。
                CMBlockBufferRef blockBuffer = CMSampleBufferGetDataBuffer(sampleBuffer);
                size_t lengthAtOffsetOutput, totalLengthOutput;
                char *dataPointer;
                
                // 2、从 CMBlockBuffer 中获取 PCM 数据存储到文件中。
                CMBlockBufferGetDataPointer(blockBuffer, 0, &lengthAtOffsetOutput, &totalLengthOutput, &dataPointer);
                [weakSelf.fileHandle writeData:[NSData dataWithBytes:dataPointer length:totalLengthOutput]];
            }
        };
    }
    
    return _audioCapture;
}

#pragma mark - Lifecycle
- (void)dealloc {
    if (_fileHandle) {
        [_fileHandle closeFile];
    }
}

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    [self setupUI];
    [self setupAudioSession];
}

- (void)setupUI {
    self.edgesForExtendedLayout = UIRectEdgeAll;
    self.extendedLayoutIncludesOpaqueBars = YES;
    self.title = @"音频采集";
    self.view.backgroundColor = [UIColor whiteColor];
    
    UIBarButtonItem *cancelBarItem = [[UIBarButtonItem alloc] initWithTitle:@"取消" style:UIBarButtonItemStylePlain target:self action:@selector(cancelClicked)];
    [cancelBarItem setTitleTextAttributes:@{NSForegroundColorAttributeName: LCColor(153, 153, 153)} forState:UIControlStateNormal];
    self.navigationItem.leftBarButtonItem = cancelBarItem;
    
    UIBarButtonItem *moreBarItem = [[UIBarButtonItem alloc] initWithTitle:@"使用音频" style:UIBarButtonItemStylePlain target:self action:@selector(moreClicked)];
    self.navigationItem.rightBarButtonItem = moreBarItem;
    
    [self.view addSubview:self.fileNameTextField];
    [self.view addSubview:self.captureBtn];
    
    [self.fileNameTextField mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.mas_equalTo(30);
        make.right.mas_equalTo(-30);
        make.top.mas_equalTo(ZEGO_IPHONE_NAVIGATIONBAR_HEIGHT + 60);
        make.height.mas_equalTo(30);
    }];
    
    [self.captureBtn mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.mas_equalTo(30);
        make.right.mas_equalTo(-30);
        make.top.equalTo(self.fileNameTextField.mas_bottom).offset(30);
        make.height.mas_equalTo(38);
    }];
}

- (void)cancelClicked {
    [self dismissViewControllerAnimated:YES completion:^{
        
    }];
}

- (void)moreClicked {
    __weak typeof(self) weakSelf = self;
    NSString *audioPath = [[NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) lastObject] stringByAppendingPathComponent:weakSelf.audioFileName];
    NSData *audioFileData = [NSData dataWithContentsOfFile:audioPath];
    if (weakSelf.useAudioFileBlock) {
        weakSelf.useAudioFileBlock(audioFileData, weakSelf.audioFileName);
    }
    [weakSelf dismissViewControllerAnimated:YES completion:nil];
    
    
//    SPAlertController *alertController = [SPAlertController alertControllerWithTitle:@"" buttonTitles:@[@"分享", @"使用音频"] redButtonIndex:-1 actionHandler:^(NSInteger buttonIndex) {
//        if (buttonIndex == 0) {
//            NSString *audioPath = [[NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) lastObject] stringByAppendingPathComponent:weakSelf.audioFileName];
//            UIDocumentInteractionController *controller = [UIDocumentInteractionController interactionControllerWithURL:[NSURL fileURLWithPath:audioPath]];
//            controller.delegate = self;
//            controller.name = self.audioFileName;
//            [controller presentPreviewAnimated:YES];
//
//        } else if (buttonIndex == 1){
//            NSString *audioPath = [[NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) lastObject] stringByAppendingPathComponent:weakSelf.audioFileName];
//            NSData *audioFileData = [NSData dataWithContentsOfFile:audioPath];
//            if (weakSelf.useAudioFileBlock) {
//                weakSelf.useAudioFileBlock(audioFileData, weakSelf.audioFileName);
//            }
//            [weakSelf dismissViewControllerAnimated:YES completion:nil];
//        }
//    }];
//    [self presentViewController:alertController animated:YES completion:nil];
}

- (void)captureBtnClicked:(UIButton *)sender {
    if (!self.isStart) {    // 开始采集
        self.isStart = YES;
        NSString *pcmFileName = [self.fileNameTextField.text stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceAndNewlineCharacterSet]];
        
        if (pcmFileName.length <= 0) {
            pcmFileName = @"test.pcm";
        }
        
        pcmFileName = [pcmFileName stringByAppendingString:@".pcm"];
        self.audioFileName = pcmFileName;
        NSString *audioPath = [[NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) lastObject] stringByAppendingPathComponent:pcmFileName];
        NSLog(@"PCM file path: %@", audioPath);
        [[NSFileManager defaultManager] removeItemAtPath:audioPath error:nil];
        [[NSFileManager defaultManager] createFileAtPath:audioPath contents:nil attributes:nil];
        self.fileHandle = [NSFileHandle fileHandleForWritingAtPath:audioPath];
        
        [self.audioCapture startRunning];
    }else{
        self.isStart = NO;
        [self.audioCapture stopRunning];
    }
    sender.selected = !sender.selected;
}

- (void)setupAudioSession {
    NSError *error = nil;
    
    // 1、获取音频会话实例。
    AVAudioSession *session = [AVAudioSession sharedInstance];

    // 2、设置分类和选项。
    [session setCategory:AVAudioSessionCategoryPlayAndRecord withOptions:AVAudioSessionCategoryOptionMixWithOthers | AVAudioSessionCategoryOptionDefaultToSpeaker error:&error];
    if (error) {
        NSLog(@"AVAudioSession setCategory error.");
        error = nil;
        return;
    }
    
    // 3、设置模式。
    [session setMode:AVAudioSessionModeVideoRecording error:&error];
    if (error) {
        NSLog(@"AVAudioSession setMode error.");
        error = nil;
        return;
    }

    // 4、激活会话。
    [session setActive:YES error:&error];
    if (error) {
        NSLog(@"AVAudioSession setActive error.");
        error = nil;
        return;
    }
}

#pragma mark - UIDocumentInteractionControllerDelegate
//必须实现的代理方法 预览窗口以模式窗口的形式显示，因此需要在该方法中返回一个view controller ，作为预览窗口的父窗口。如果你不实现该方法，或者在该方法中返回 nil，或者你返回的 view controller 无法呈现模式窗口，则该预览窗口不会显示。
- (UIViewController *)documentInteractionControllerViewControllerForPreview:(UIDocumentInteractionController *)controller{
    
    return self;
}

- (UIView*)documentInteractionControllerViewForPreview:(UIDocumentInteractionController*)controller {
    
    return self.view;
}

- (CGRect)documentInteractionControllerRectForPreview:(UIDocumentInteractionController*)controller {
    
    return CGRectMake(0, 0, self.view.bounds.size.width, self.view.bounds.size.height);
}

@end
