//
//  ZegoAudioFileListViewController.m
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/11/25.
//

#import "ZegoAudioFileListViewController.h"
#import <Masonry/Masonry.h>
#import "ZegoGlobalDefines.h"

@interface ZegoAudioFileListViewController ()<UITableViewDelegate, UITableViewDataSource>
@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, strong) NSArray<NSString *> *dataSource;
@property (nonatomic, assign) NSInteger selectIndex;
@end

@implementation ZegoAudioFileListViewController

- (UITableView *)tableView {
    if (!_tableView) {
        _tableView = [[UITableView alloc] initWithFrame:CGRectZero style:UITableViewStylePlain];
        _tableView.rowHeight = 44;
        _tableView.delegate = self;
        _tableView.dataSource = self;
        _tableView.backgroundColor = [UIColor whiteColor];
        [_tableView registerClass:UITableViewCell.class forCellReuseIdentifier:@"ZegoAudioFileListCell"];
        _tableView.tableFooterView = [UIView new];
    }
    return _tableView;
}

- (NSArray<NSString *> *)dataSource {
    if (!_dataSource) {
        _dataSource = @[@"不选择音频文件", @"阿拉伯语", @"英语", @"法语", @"韩语", @"马来语", @"越南语", @"印尼语"];
    }
    return _dataSource;
}

#pragma mark - LifeCycle
- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    self.view.backgroundColor = [UIColor whiteColor];
    UIBarButtonItem *cancelBarItem = [[UIBarButtonItem alloc] initWithTitle:@"取消" style:UIBarButtonItemStylePlain target:self action:@selector(cancelClicked)];
    [cancelBarItem setTitleTextAttributes:@{NSForegroundColorAttributeName: LCColor(153, 153, 153)} forState:UIControlStateNormal];
    self.navigationItem.leftBarButtonItem = cancelBarItem;
    
    UIBarButtonItem *confirmBarItem = [[UIBarButtonItem alloc] initWithTitle:@"确定" style:UIBarButtonItemStylePlain target:self action:@selector(confirmClicked)];
    self.navigationItem.rightBarButtonItem = confirmBarItem;
    
    [self.view addSubview:self.tableView];
    [self.tableView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.edges.mas_equalTo(0);
    }];
}

#pragma mark - Action
- (void)cancelClicked {
    [self dismissViewControllerAnimated:YES completion:nil];
}

- (void)confirmClicked {
    if (self.selectIndex == 0) {
        __weak typeof(self) weakSelf = self;
        [self dismissViewControllerAnimated:YES completion:^{
            if (weakSelf.selectAudioFileBlock) {
                weakSelf.selectAudioFileBlock(@"", nil);
            }
        }];
    }else{
        NSArray<NSString *> *pcmFilenames = @[@"", @"arabic.pcm", @"english.pcm", @"french.pcm", @"Korean.pcm", @"malay.pcm", @"vi.pcm", @"yini.pcm"];
        NSString *pcmFilePath = [[NSBundle mainBundle] pathForResource:pcmFilenames[self.selectIndex] ofType:@"pcm"];
        NSString *filename = [pcmFilenames objectAtIndex:self.selectIndex];
        NSData *pcmData = [NSData dataWithContentsOfFile:pcmFilePath];
        __weak typeof(self) weakSelf = self;
        [self dismissViewControllerAnimated:YES completion:^{
            if (weakSelf.selectAudioFileBlock) {
                weakSelf.selectAudioFileBlock(filename, pcmData);
            }
        }];
    }
    
}

#pragma mark - UITableViewDelegate & UITableViewDataSource
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.dataSource.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"ZegoAudioFileListCell"];
    cell.textLabel.text = self.dataSource[indexPath.row];
    if (indexPath.row == self.selectIndex) {
        cell.accessoryType = UITableViewCellAccessoryCheckmark;
    } else {
        cell.accessoryType = UITableViewCellAccessoryNone;
    }
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    [tableView deselectRowAtIndexPath:indexPath animated:NO];
    
    self.selectIndex = indexPath.row;
    [self.tableView reloadData];
}

@end
