//
//  ZegoLanguageListViewController.m
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/11/16.
//

#import "ZegoLanguageListViewController.h"
#import <Masonry/Masonry.h>
#import "ZegoGlobalDefines.h"
#import "ZegoSdkConfig.h"

@interface ZegoLanguageListViewController ()<UITableViewDelegate, UITableViewDataSource>
@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, strong) NSArray *dataSource;
@property (nonatomic, strong) NSMutableDictionary<NSString *, ZegoSpeechLanguageModel *> *speechLanguageDict;
@property (nonatomic, strong) NSMutableDictionary<NSString *, ZegoTransLanguageModel *> *transLanguageDict;
@end

@implementation ZegoLanguageListViewController
#pragma mark - LifeCycle
- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    self.view.backgroundColor = [UIColor whiteColor];
    UIBarButtonItem *cancelBarItem = [[UIBarButtonItem alloc] initWithTitle:@"取消" style:UIBarButtonItemStylePlain target:self action:@selector(cancelClicked)];
    [cancelBarItem setTitleTextAttributes:@{NSForegroundColorAttributeName: LCColor(153, 153, 153)} forState:UIControlStateNormal];
    self.navigationItem.leftBarButtonItem = cancelBarItem;
    
    UIBarButtonItem *confirmBarItem = [[UIBarButtonItem alloc] initWithTitle:@"确定" style:UIBarButtonItemStylePlain target:self action:@selector(confirmClicked)];
    self.navigationItem.rightBarButtonItem = confirmBarItem;
    
    [self.view addSubview:self.tableView];
    [self.tableView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.edges.mas_equalTo(0);
    }];
    
    [self getData];
}

- (void)getData {
    if (self.isSpeech) {
        self.dataSource = [self.langDataSource loadSpeechLanguageList];
        [self.speechLanguageDict removeAllObjects];
        for (ZegoSpeechLanguageModel *model in self.dataSource) {
            [self.speechLanguageDict setObject:model forKey:@(model.language).stringValue];
        }
    }else {
        self.dataSource = [self.langDataSource loadTransLanguageListIsTextTranslation:self.isTextTranslation];
        [self.transLanguageDict removeAllObjects];
        for (ZegoTransLanguageModel *model in self.dataSource) {
            [self.transLanguageDict setObject:model forKey:@(model.language).stringValue];
        }
    }
    [self.tableView reloadData];
}

- (void)setTranslateLanguage:(ZegoTranslationLanguage)translateLanguage {
    _translateLanguage = translateLanguage;
    
    [self.tableView reloadData];
}

- (void)setSpeechLanguage:(ZegoSpeechLanguage)speechLanguage {
    _speechLanguage = speechLanguage;
    
    [self.tableView reloadData];
}

#pragma mark - Action
- (void)cancelClicked {
    [self dismissViewControllerAnimated:YES completion:nil];
}

- (void)confirmClicked {
    __weak typeof(self) weakSelf = self;
    [self dismissViewControllerAnimated:YES completion:^{
        if (weakSelf.isSpeech) {
            if (weakSelf.selectSpeechLanguageBlock) {
                ZegoSpeechLanguageModel *model = [weakSelf.speechLanguageDict objectForKey:@(weakSelf.speechLanguage).stringValue];
                weakSelf.selectSpeechLanguageBlock(model);
                
            }
        }else{
            if (weakSelf.selectTranslateLanguageBlock) {
                ZegoTransLanguageModel *model = [weakSelf.transLanguageDict objectForKey:@(weakSelf.translateLanguage).stringValue];
                weakSelf.selectTranslateLanguageBlock(model);
            }
        }
    }];
}

#pragma mark - UITableViewDelegate & UITableViewDataSource
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.dataSource.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"ZegoLanguageListCell"];
    if (self.isSpeech) {
        ZegoSpeechLanguageModel *model = [self.dataSource objectAtIndex:indexPath.row];
        cell.textLabel.text = model.language_name;
        cell.accessoryType = model.language == self.speechLanguage ? UITableViewCellAccessoryCheckmark : UITableViewCellAccessoryNone;
    }else{
        ZegoTransLanguageModel *model = [self.dataSource objectAtIndex:indexPath.row];
        cell.textLabel.text = model.language_name;
        cell.accessoryType = model.language == self.translateLanguage ? UITableViewCellAccessoryCheckmark : UITableViewCellAccessoryNone;
    }
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    [tableView deselectRowAtIndexPath:indexPath animated:NO];
    
    if (self.isSpeech) {
        ZegoSpeechLanguageModel *model = [self.dataSource objectAtIndex:indexPath.row];
        self.speechLanguage = model.language;
    } else {
        ZegoTransLanguageModel *model = [self.dataSource objectAtIndex:indexPath.row];
        self.translateLanguage = model.language;
    }
    [self.tableView reloadData];
}

#pragma mark - Property
- (UITableView *)tableView {
    if (!_tableView) {
        _tableView = [[UITableView alloc] initWithFrame:CGRectZero style:UITableViewStylePlain];
        _tableView.rowHeight = 44;
        _tableView.delegate = self;
        _tableView.dataSource = self;
        _tableView.backgroundColor = [UIColor whiteColor];
        [_tableView registerClass:UITableViewCell.class forCellReuseIdentifier:@"ZegoLanguageListCell"];
        _tableView.tableFooterView = [UIView new];
    }
    return _tableView;
}

- (NSMutableDictionary<NSString *,ZegoSpeechLanguageModel *> *)speechLanguageDict {
    if (!_speechLanguageDict) {
        _speechLanguageDict = [NSMutableDictionary dictionary];
    }
    return _speechLanguageDict;
}

- (NSMutableDictionary<NSString *,ZegoTransLanguageModel *> *)transLanguageDict {
    if (!_transLanguageDict) {
        _transLanguageDict = [NSMutableDictionary dictionary];
    }
    return _transLanguageDict;
}

@end
