//
//  ZegoListViewController.m
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/11/5.
//

#import "ZegoListViewController.h"
#import <Masonry/Masonry.h>
#import "ZegoGlobalDefines.h"
#import "ZegoSdkConfig.h"

@interface ZegoListViewController ()<UITableViewDelegate, UITableViewDataSource>
@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, strong) NSArray *dataSource;
@property (nonatomic, assign) NSInteger selectIndex;
@property (nonatomic, strong) NSArray *serviceProviders;
@end

@implementation ZegoListViewController
- (UITableView *)tableView {
    if (!_tableView) {
        _tableView = [[UITableView alloc] initWithFrame:CGRectZero style:UITableViewStylePlain];
        _tableView.rowHeight = 44;
        _tableView.delegate = self;
        _tableView.dataSource = self;
        _tableView.backgroundColor = [UIColor whiteColor];
        [_tableView registerClass:UITableViewCell.class forCellReuseIdentifier:@"ZegoSdkListCell"];
        _tableView.tableFooterView = [UIView new];
    }
    return _tableView;
}

- (NSArray *)serviceProviders {
    if (!_serviceProviders) {
        _serviceProviders = @[
            @(ZegoRTServiceProviderIflytek),
            @(ZegoRTServiceProviderGoogle),
            @(ZegoRTServiceProviderLiveData)];
    }
    return _serviceProviders;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    self.view.backgroundColor = [UIColor whiteColor];
    UIBarButtonItem *cancelBarItem = [[UIBarButtonItem alloc] initWithTitle:@"取消" style:UIBarButtonItemStylePlain target:self action:@selector(cancelClicked)];
    [cancelBarItem setTitleTextAttributes:@{NSForegroundColorAttributeName: LCColor(153, 153, 153)} forState:UIControlStateNormal];
    self.navigationItem.leftBarButtonItem = cancelBarItem;
    
    UIBarButtonItem *confirmBarItem = [[UIBarButtonItem alloc] initWithTitle:@"确定" style:UIBarButtonItemStylePlain target:self action:@selector(confirmClicked)];
    self.navigationItem.rightBarButtonItem = confirmBarItem;
    
    [self.view addSubview:self.tableView];
    [self.tableView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.edges.mas_equalTo(0);
    }];
    
    [self getData];
    
}

- (void)getData {
    NSMutableArray *providerNames = [NSMutableArray new];
    for (NSInteger i = 0; i < self.serviceProviders.count; i++) {
        ZegoRTServiceProvider service = [self.serviceProviders[i] intValue];
        NSString *providerName = [[ZegoSdkConfig config] getThirdServiceProviderName:service];
        [providerNames addObject:providerName];
    }
    self.dataSource = providerNames;
    if (self.service == ZegoRTServiceProviderIflytek) {
        self.selectIndex = 0;
    }else if (self.service == ZegoRTServiceProviderGoogle) {
        self.selectIndex = 1;
    } else if (self.service == ZegoRTServiceProviderLiveData) {
        self.selectIndex = 2;
    }
    
    [self.tableView reloadData];
}

#pragma mark - Action
- (void)cancelClicked {
    [self dismissViewControllerAnimated:YES completion:nil];
}

- (void)confirmClicked {
    __weak typeof(self) weakSelf = self;
    [self dismissViewControllerAnimated:YES completion:^{
        if (weakSelf.selectedSDKBlock) {
            ZegoRTServiceProvider provider = [[weakSelf.serviceProviders objectAtIndex:weakSelf.selectIndex] intValue];
            weakSelf.selectedSDKBlock(provider);
        }
    }];
}

#pragma mark - UITableViewDelegate & UITableViewDataSource
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.dataSource.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"ZegoSdkListCell"];
    cell.textLabel.text = [self.dataSource objectAtIndex:indexPath.row];
    if (indexPath.row == self.selectIndex) {
        cell.accessoryType = UITableViewCellAccessoryCheckmark;
    } else {
        cell.accessoryType = UITableViewCellAccessoryNone;
    }
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    [tableView deselectRowAtIndexPath:indexPath animated:NO];
    
    self.selectIndex = indexPath.row;
    [self.tableView reloadData];
}
@end
