//
//  ZegoRoomViewController.m
//  ZegoRTVTDemo
//
//  Created by zego on 2022/10/18.
//

#import "ZegoRoomViewController.h"
#import <Masonry/Masonry.h>
#import <sys/utsname.h>
#import <ZegoRealtimeTranslation/ZegoRealtimeTranslation.h>
#import "ZegoGlobalDefines.h"
#import "RTCEngineManager.h"
#import "ZegoSdkConfig.h"
#import "RecognizedModel.h"
#import "ZegoTabChangeView.h"
#import "ZegoRealtimeTranslateView.h"
#import "ZegoTextTranslateView.h"
#import "ZegoListViewController.h"
#import <MJExtension/MJExtension.h>
#import "ZegoLanguageListViewController.h"
#import "ZegoAudioFileListViewController.h"
#import "ZegoAudioCaptureViewController.h"
#import "SPAlertController.h"
#import "PCMFilePlayer.h"
#import "ZegoHudManager.h"
#import "ZegoLanguageListDataSource.h"
#import "KeyCenter.h"

@implementation ZegoRoomUser

static int const MAX_REALTIME_TRANSLATE_TIME = 2 * 60;  // 最大实时传译时间2分钟

- (instancetype)initWithRoomID:(NSString *)roomID roomName:(NSString *)roomName userID:(NSString *)userID userName:(NSString *)userName isHost:(BOOL)isHost {
    self = [super init];
    if (self) {
        self.roomID = roomID;
        self.roomName = roomName;
        self.userID = userID;
        self.userName = userName;
        self.isHost = isHost;
    }
    return self;
}
@end

@interface ZegoRoomViewController ()<IZegoRealtimeTranslationHandler, UIDocumentInteractionControllerDelegate,SPAlertControllerDelegate, ZegoLanguageListDataSource>
@property (nonatomic, strong) UIView *localPreviewView;
@property (nonatomic, strong) UIView *remotePreviewView;
@property (nonatomic, strong) UILabel *localUserNameLab;
@property (nonatomic, strong) UILabel *remoteUserNameLab;
@property (nonatomic, strong) ZegoRealtimeTranslation *realtimeTranslation;
@property (nonatomic, strong) RTCEngineManager *rtcManager;
@property (nonatomic, strong) NSMutableString *translateResult;
@property (nonatomic, strong) NSMutableString *recogizedResult;
@property (nonatomic, strong) ZegoTabChangeView *tabChangeView;
@property (nonatomic, strong) ZegoRealtimeTranslateView *realtimeTranslateView;
@property (nonatomic, strong) ZegoTextTranslateView *textTranslateView;
@property (nonatomic, strong) UIButton *selectLanguageFileBtn;
@property (nonatomic, assign) BOOL isSelectAudioFile;
@property (nonatomic, copy) NSString *pcmFileName;
@property (nonatomic, strong) NSData *pcmFileData;
@property (nonatomic, strong) NSMutableArray<NSString *> *recognizeList;
@property (nonatomic, strong) NSMutableArray<NSString *> *translateList;
@property (nonatomic, copy) NSString *pcmFilePath;

@end

@implementation ZegoRoomViewController
static NSString *const TAG = @"ZegoRoomViewController";

#pragma mark - LifeCycle
- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    self.view.backgroundColor = [UIColor whiteColor];
    
    self.rtcManager = [RTCEngineManager sharedManager];
    [self.rtcManager addRTCEventListener:self];
    self.realtimeTranslation = [ZegoRealtimeTranslation getInstance];

    NSString *license = [KeyCenter license];
    int ret = [self.realtimeTranslation init:license];
    if (ret != ZegoRealtimeTranslationErrorSuccess) {
        [self showErrorMessage:ret];
    }
    
    [self.realtimeTranslation setRealtimeTranslationHandler:self];
    self.translateResult = [NSMutableString new];
    self.recogizedResult = [NSMutableString new];
    self.title = [NSString stringWithFormat:@"房间%@", self.roomUser.roomName];
    UIBarButtonItem *leftBarItem = [[UIBarButtonItem alloc] initWithTitle:@"返回" style:UIBarButtonItemStylePlain target:self action:@selector(backAction)];
    self.navigationItem.leftBarButtonItem = leftBarItem;
    
//    UIBarButtonItem *rightBarItem = [[UIBarButtonItem alloc] initWithTitle:@"音频采集" style:UIBarButtonItemStylePlain target:self action:@selector(captureAction)];
//    self.navigationItem.rightBarButtonItem = rightBarItem;
    
    [self setupUI];
    // 设为YES则保持常亮，不自动锁屏，默认为NO会自动锁屏
    [[UIApplication sharedApplication] setIdleTimerDisabled:YES];
    
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(pcmTotalTestComplete:) name:@"PCMTotalTestCompleteNotification" object:nil];
}

- (void)pcmTotalTestComplete:(NSNotification *)notification
{
    UIAlertController *alertVc = [UIAlertController alertControllerWithTitle:@"提示" message:@"pcm 文件全部测试完了" preferredStyle:UIAlertControllerStyleAlert];
    UIAlertAction *okAction = [UIAlertAction actionWithTitle:@"确定" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
        
    }];
    [alertVc addAction:okAction];
    [self presentViewController:alertVc animated:YES completion:nil];
}

- (void)setupUI {
    [self.view addSubview:self.localPreviewView];
    [self.view addSubview:self.remotePreviewView];
    [self.view addSubview:self.tabChangeView];
    [self.view addSubview:self.realtimeTranslateView];
    [self.view addSubview:self.textTranslateView];
    [self.view addSubview:self.localUserNameLab];
    [self.view addSubview:self.remoteUserNameLab];
    [self.view addSubview:self.selectLanguageFileBtn];
    
    CGFloat previewHeight = [self previerViewHeight];
    
    
    [self.localPreviewView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.mas_equalTo(ZEGO_IPHONE_NAVIGATIONBAR_HEIGHT);
        make.left.mas_equalTo(0);
        make.right.mas_equalTo(0);
        make.height.mas_equalTo(previewHeight);
    }];
    
    [self.localUserNameLab mas_makeConstraints:^(MASConstraintMaker *make) {
        make.right.equalTo(self.localPreviewView.mas_right).offset(-10);
        make.bottom.equalTo(self.localPreviewView.mas_bottom).offset(-10);
    }];
    
    [self.remoteUserNameLab mas_makeConstraints:^(MASConstraintMaker *make) {
        make.right.equalTo(self.remotePreviewView.mas_right).offset(-10);
        make.bottom.equalTo(self.remotePreviewView.mas_bottom).offset(-10);
    }];
    
    [self.tabChangeView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(self.localPreviewView.mas_bottom).offset(5);
        make.right.mas_equalTo(0);
        make.left.mas_equalTo(10);
        make.height.mas_equalTo(22.0);
    }];
    
    [self.realtimeTranslateView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.right.bottom.mas_equalTo(0);
        make.top.equalTo(self.tabChangeView.mas_bottom).offset(5);
    }];
    
    [self.textTranslateView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.right.bottom.mas_equalTo(0);
        make.top.equalTo(self.tabChangeView.mas_bottom).offset(5);
    }];
    
    [self.selectLanguageFileBtn mas_makeConstraints:^(MASConstraintMaker *make) {
        make.right.mas_equalTo(-10);
        make.width.mas_equalTo(110);
        make.height.mas_equalTo(20);
        make.centerY.equalTo(self.tabChangeView.mas_centerY);
    }];
        
    NSArray<ZegoSteamInfo *> *streamInfoList = self.rtcManager.streamInfoList;
    if (self.roomUser.isHost) {
        // 先判断是否已经有达到上限的主播在房间里了
        if (self.rtcManager.streamInfoList.count >= MAX_HOST_NUMBER) {
            SPAlertController *alertVc = [SPAlertController alertControllerWithTitle:@"提示" message:@"主播人数已满，请换个房间。" preferredStyle:SPAlertControllerStyleAlert];
            alertVc.delegate = self;
            SPAlertAction *confirmAction = [SPAlertAction actionWithTitle:@"确定" style:SPAlertActionStyleDefault handler:^(SPAlertAction * _Nonnull action) {

            }];
            [alertVc addAction:confirmAction];
            [self presentViewController:alertVc animated:YES completion:nil];
            return;
        }else{
            self.localUserNameLab.text = self.roomUser.userName;
            [self.rtcManager startPreview:self.localPreviewView];
            [self.rtcManager startPublishStream];
        }
    }else{
        self.selectLanguageFileBtn.hidden = YES;
    }
    
    if (streamInfoList.count > 0) {
        [self handleStreamAdded:streamInfoList];
    }
    
    [self.realtimeTranslateView refreshUIByUserRole:self.roomUser.isHost];
}

- (void)backAction {
    NSLog(@"%@ [backAction]", TAG);
    [self.realtimeTranslation unInit];
    [self.rtcManager stopPublishStream];
    [self.rtcManager removeRTCEventListener:self];
    [self.rtcManager logoutRoom];
    [self.rtcManager unInitRtc:^{

    }];
    [self.rtcManager.streamInfoList removeAllObjects];
    [self.navigationController popViewControllerAnimated:YES];
}

- (void)resetData {
    self.recognizeList = [NSMutableArray arrayWithArray:@[@""]];
    self.translateList = [NSMutableArray arrayWithArray:@[@""]];
    self.realtimeTranslateView.recognizedTextList = self.recognizeList;
    self.realtimeTranslateView.translateTextList = self.translateList;
}

- (void)captureAction {
    ZegoAudioCaptureViewController *captureVc = [[ZegoAudioCaptureViewController alloc] init];
    __weak typeof(self) weakSelf = self;
    captureVc.useAudioFileBlock = ^(NSData * _Nullable audioFileData, NSString * _Nonnull audioFileName) {
        [weakSelf.selectLanguageFileBtn setTitle:audioFileName forState:UIControlStateNormal];
        weakSelf.isSelectAudioFile = YES;
        weakSelf.pcmFileData = audioFileData;
        weakSelf.pcmFileName = audioFileName;
        NSString *audioPath = [[NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES) lastObject] stringByAppendingPathComponent:audioFileName];
        weakSelf.pcmFilePath = audioPath;
        
    };
    UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:captureVc];
    nav.modalPresentationStyle = UIModalPresentationFullScreen;
    [self presentViewController:nav animated:YES completion:nil];
}

- (void)selectLanguageFileBtnClicked:(UIButton *)sender {
    ZegoAudioFileListViewController *audioFileListVc = [ZegoAudioFileListViewController new];
    __weak typeof(self) weakSelf = self;
   
    audioFileListVc.selectAudioFileBlock = ^(NSString * _Nullable fileName, NSData * _Nonnull pcmData) {
        if (fileName.length <= 0) {
            [weakSelf.selectLanguageFileBtn setTitle:@"选择音频文件" forState:UIControlStateNormal];
            weakSelf.isSelectAudioFile = NO;
        }else{
            [weakSelf.selectLanguageFileBtn setTitle:fileName forState:UIControlStateNormal];
            weakSelf.isSelectAudioFile = YES;
            weakSelf.pcmFileData = pcmData;
            weakSelf.pcmFileName = fileName;
            weakSelf.pcmFilePath = [[NSBundle mainBundle] pathForResource:fileName ofType:@""];
        }
    };
    UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:audioFileListVc];
    nav.modalPresentationStyle = UIModalPresentationFullScreen;
    [self presentViewController:nav animated:YES completion:nil];
}

- (void)dealloc {
    NSLog(@"%@ [dealloc]", TAG);
    [[UIApplication sharedApplication] setIdleTimerDisabled:NO];
}

#pragma mark - Action
/// 处理流增加
/// - Parameter streamInfoList: 流信息列表
- (void)handleStreamAdded:(NSArray<ZegoSteamInfo *> *)streamInfoList {
    for (ZegoSteamInfo *streamInfo in streamInfoList) {
        NSLog(@"%@ [handleStreamAdded] %@", TAG, streamInfo.streamID);
        if ([streamInfo.streamID hasPrefix:STREAM_PREFIX]) {
            if ([streamInfo.streamID isEqualToString:self.rtcManager.publishStreamID]) {
                continue;
            }
            [self refreshHostView];
        }
    }
}

- (void)refreshHostView {
    NSArray<ZegoSteamInfo *> *streamInfoList = self.rtcManager.streamInfoList;
    for (ZegoSteamInfo *stream in streamInfoList) {
        NSLog(@"%@ [refreshHostView] streamID: %@, userID: %@, username: %@",TAG, stream.streamID, stream.userID, stream.userName);
    }
    NSInteger total = streamInfoList.count;
    NSLog(@"%@ [refreshHostView] stream count: %ld", TAG, total);
    
    // 如果自己是观众，那么根据流的数量分配视图给主播来进行拉流
    if (!self.roomUser.isHost) {
        for (NSInteger i = 0; i < total; i++) {
            ZegoSteamInfo *streamInfo = [streamInfoList objectAtIndex:i];
            
            if (i == 0) {
                self.localUserNameLab.text = streamInfo.userName;
                [self.rtcManager startPlayingStream:streamInfo.streamID view:self.localPreviewView];
            }else{
                self.remoteUserNameLab.text = streamInfo.userName;
                [self.rtcManager startPlayingStream:streamInfo.streamID view:self.remotePreviewView];
            }
        }
    }else{
        // 如果自己是主播，那就分配remote给其它主播
        for (NSInteger i = 0; i < total; i++) {
            ZegoSteamInfo *streamInfo = [streamInfoList objectAtIndex:i];
            NSLog(@"%@ [refreshHostView] %@", TAG, streamInfo.streamID);
            if ([streamInfo.streamID isEqualToString:self.rtcManager.publishStreamID]) {
                [self.rtcManager startPreview:self.localPreviewView];
            }else{
                self.remoteUserNameLab.text = streamInfo.userName;
                [self.rtcManager startPlayingStream:streamInfo.streamID view:self.remotePreviewView];
            }
        }
    }

    CGFloat previewHeight = [self previerViewHeight];
    if (total == 1) {
        [self.localPreviewView mas_remakeConstraints:^(MASConstraintMaker *make) {
            make.top.mas_equalTo(ZEGO_IPHONE_NAVIGATIONBAR_HEIGHT);
            make.left.mas_equalTo(0);
            make.right.mas_equalTo(0);
            make.height.mas_equalTo(previewHeight);
        }];

        [self.remotePreviewView mas_remakeConstraints:^(MASConstraintMaker *make) {
            make.top.mas_equalTo(ZEGO_IPHONE_NAVIGATIONBAR_HEIGHT);
            make.right.mas_equalTo(0);
            make.width.mas_equalTo(0);
            make.height.mas_equalTo(0);
        }];

    } else if (total >= 2){
        [self.localPreviewView mas_remakeConstraints:^(MASConstraintMaker *make) {
            make.top.mas_equalTo(ZEGO_IPHONE_NAVIGATIONBAR_HEIGHT);
            make.left.mas_equalTo(0);
            make.width.mas_equalTo(SCREEN_SIZE.width/2.0);
            make.height.mas_equalTo(previewHeight);
        }];

        [self.remotePreviewView mas_remakeConstraints:^(MASConstraintMaker *make) {
            make.top.mas_equalTo(ZEGO_IPHONE_NAVIGATIONBAR_HEIGHT);
            make.right.mas_equalTo(0);
            make.width.mas_equalTo(SCREEN_SIZE.width/2.0);
            make.height.mas_equalTo(previewHeight);
        }];
    }
}

#pragma mark - IZegoRealtimeTranslationHandler
- (void)onRecognizingText:(NSString *)sttText {
    NSString *username = self.roomUser.userName;
    self.realtimeTranslateView.recognizeText = [NSString stringWithFormat:@"%@%@:%@\n", self.recogizedResult, username, sttText];
    NSString *showSttText = [NSString stringWithFormat:@"%@:%@", username, sttText];
    [self.recognizeList replaceObjectAtIndex:self.recognizeList.count - 1 withObject:showSttText];
            
    self.realtimeTranslateView.recognizedTextList = self.recognizeList;
    // 不带文本翻译结果
    RecognizedModel *recognizedModel = [RecognizedModel new];
    recognizedModel.username = username;
    recognizedModel.text = sttText;
    NSString *jsonStr = [recognizedModel mj_JSONString];
    [self.rtcManager sendRecognizingText:jsonStr];
}

- (void)onRecognizingTranslatedText:(NSString *)translatedText {
    NSString *username = self.roomUser.userName;
    self.realtimeTranslateView.translateText = [NSString stringWithFormat:@"%@%@:%@\n", self.translateResult, username, translatedText];
    
    NSString *showTransText = [NSString stringWithFormat:@"%@:%@", username, translatedText];
    [self.translateList replaceObjectAtIndex:self.translateList.count-1 withObject:showTransText];
    self.realtimeTranslateView.translateTextList = self.translateList;
    // 不带语音识别结果
    RecognizedModel *recognizedModel = [RecognizedModel new];
    recognizedModel.username = username;
    recognizedModel.trans = translatedText;
    NSString *jsonStr = [recognizedModel mj_JSONString];
    [self.rtcManager sendRecognizingText:jsonStr];
}

- (void)onRecognizedText:(NSString *)sttText {
    NSString *username = self.roomUser.userName;
    RecognizedModel *recognizedModel = [RecognizedModel new];
    recognizedModel.username = username;
    recognizedModel.text = sttText;
    NSString *jsonStr = [recognizedModel mj_JSONString];
    [self.rtcManager sendRecognizedText:jsonStr];
        
    NSString *showSttText = [NSString stringWithFormat:@"%@:%@", username, sttText];
    [self.recognizeList replaceObjectAtIndex:self.recognizeList.count-1 withObject:showSttText];
    [self.recognizeList addObject:@" "];
    self.realtimeTranslateView.recognizedTextList = self.recognizeList;
}

- (void)onRecognizedTranslatedText:(NSString *)translatedText {
    NSString *username = self.roomUser.userName;
    RecognizedModel *recognizedModel = [RecognizedModel new];
    recognizedModel.username = username;
    recognizedModel.trans = translatedText;
    NSString *jsonStr = [recognizedModel mj_JSONString];
    [self.rtcManager sendRecognizedText:jsonStr];
    
    NSString *showTransText = [NSString stringWithFormat:@"%@:%@", username, translatedText];
    [self.translateList replaceObjectAtIndex:self.translateList.count-1 withObject:showTransText];
    [self.translateList addObject:@" "];
    self.realtimeTranslateView.translateTextList = self.translateList;
}

- (void)onRecognizingText:(NSString *)sttText translatedText:(NSString *)translatedText {
    
}

- (void)onRecognizedText:(NSString *)sttText translatedText:(NSString *)translatedText {
    NSLog(@"-----aa: %@\n-----bb: %@", sttText, translatedText);
}

- (void)onError:(int)errorCode {
    [self showErrorMessage:errorCode];
}

#pragma mark - IRTCEventListener
- (void)onRecognizingSEIText:(NSString *)jsonStr {
    NSLog(@"%@ [onRecognizingSEIText] SEI: %@", TAG, jsonStr);
    RecognizedModel *recogizedModel = [RecognizedModel mj_objectWithKeyValues:jsonStr];
    if (recogizedModel.text.length > 0) {
        self.realtimeTranslateView.recognizeText =  [NSString stringWithFormat:@"%@%@:%@\n", self.recogizedResult, recogizedModel.username, recogizedModel.text];
                
        NSString *sttText = [NSString stringWithFormat:@"%@:%@", recogizedModel.username, recogizedModel.text];
        [self.recognizeList replaceObjectAtIndex:self.recognizeList.count-1 withObject:sttText];
        self.realtimeTranslateView.recognizedTextList = self.recognizeList;
    }
    
    if (recogizedModel.trans.length > 0) {
        self.realtimeTranslateView.translateText = [NSString stringWithFormat:@"%@%@:%@\n", self.translateResult, recogizedModel.username, recogizedModel.trans];
        
        NSString *transText = [NSString stringWithFormat:@"%@:%@", recogizedModel.username, recogizedModel.trans];
        [self.translateList replaceObjectAtIndex:self.translateList.count-1 withObject:transText];
        self.realtimeTranslateView.translateTextList = self.translateList;
    }
}

- (void)onRecognizedSEIText:(NSString *)jsonstr {
    NSLog(@"%@ [onRecognizedSEIText] SEI: %@", TAG, jsonstr);
    RecognizedModel *recogizedModel = [RecognizedModel mj_objectWithKeyValues:jsonstr];
    
    if (recogizedModel.text.length > 0) {   // 语音识别文本
        NSString *sttText = recogizedModel.text;
        sttText = [NSString stringWithFormat:@"%@:%@", recogizedModel.username, sttText];
        [self.recognizeList replaceObjectAtIndex:self.recognizeList.count-1 withObject:sttText];
        [self.recognizeList addObject:@" "];
        self.realtimeTranslateView.recognizedTextList = self.recognizeList;
    }
    
    if (recogizedModel.trans.length > 0) {
        NSString *translatedText = recogizedModel.trans;
        NSString *transText = [NSString stringWithFormat:@"%@:%@", recogizedModel.username, translatedText];
        [self.translateList replaceObjectAtIndex:self.translateList.count-1 withObject:transText];
        [self.translateList addObject:@" "];
        self.realtimeTranslateView.translateTextList = self.translateList;
    }
}

- (void)onStreamAdd:(NSArray<ZegoSteamInfo *> *)streamInfoList {
    [self handleStreamAdded:streamInfoList];
}

- (void)onStreamRemove:(NSArray<ZegoSteamInfo *> *)streamInfoList {
    for (ZegoSteamInfo *streamInfo in streamInfoList) {
        if ([streamInfo.streamID hasPrefix:STREAM_PREFIX]) {
            [self.rtcManager stopPlayingStream:streamInfo.streamID];
            [self refreshHostView];
        }
    }
}

- (void)onRoomStateChanged:(RTCEngineRoomStateChangedReason)reason {
    // 被挤登录的话停止识别
    [[ZegoRealtimeTranslation getInstance] stopRealtimeTranslation];
    if (reason == RTCEngineRoomStateChangedReasonKickOut) {
        [self.rtcManager removeRTCEventListener:self];
        [self.rtcManager logoutRoom];
        __weak typeof(self) weakSelf = self;
        dispatch_async(dispatch_get_main_queue(), ^{
            [weakSelf showAlertController:@"提示" message:@"你已在其他设备登录。" handler:^{
                [weakSelf.navigationController popViewControllerAnimated:YES];
            }];
        });
    } else if (reason == RTCEngineRoomStateChangedReasonDisconnect) {
        [self.rtcManager removeRTCEventListener:self];
        [self.rtcManager logoutRoom];
        __weak typeof(self) weakSelf = self;
        dispatch_async(dispatch_get_main_queue(), ^{
            [weakSelf showAlertController:@"提示" message:@"你已经离线。" handler:^{
                [weakSelf.navigationController popViewControllerAnimated:YES];
            }];
        });
    }
}

- (void)realtimeTranslateSet:(NSInteger)tag {
    if (tag == 0 || tag == 1) {   // 设置语言
        ZegoLanguageListViewController *langugaListVc = [ZegoLanguageListViewController new];
        langugaListVc.isTextTranslation = NO;
        langugaListVc.langDataSource = self;
        if (tag == 0) {    // 设置语音识别的语言
            langugaListVc.speechLanguage = self.realtimeTranslateView.sourceLanguage;
            langugaListVc.isSpeech = YES;
        }else {
            langugaListVc.translateLanguage = self.realtimeTranslateView.targetLanguage;
            langugaListVc.isSpeech = NO;
        }
        
        __weak typeof(self) weakSelf = self;
        langugaListVc.selectSpeechLanguageBlock = ^(ZegoSpeechLanguageModel * _Nonnull speechModel) {
            weakSelf.realtimeTranslateView.sourceLanguage = speechModel.language;
        };
        langugaListVc.selectTranslateLanguageBlock = ^(ZegoTransLanguageModel * _Nonnull translateModel) {
            weakSelf.realtimeTranslateView.targetLanguage = translateModel.language;
        };
        UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:langugaListVc];
        nav.modalPresentationStyle = UIModalPresentationFullScreen;
        [self presentViewController:nav animated:YES completion:nil];
    }else{
        ZegoListViewController *listVc = [ZegoListViewController new];
        if (tag == 2) {   // 语音识别服务供应商
            listVc.service = self.realtimeTranslateView.speechProvider;
        }else if (tag == 3) {   // 文本翻译服务供应商
            listVc.service = self.realtimeTranslateView.translateProvider;
        }
        __weak typeof(self) weakSelf = self;
        
        listVc.selectedSDKBlock = ^(ZegoRTServiceProvider thirdPartyServiceProvider) {
            if (tag == 2) {
                weakSelf.realtimeTranslateView.speechProvider = thirdPartyServiceProvider;
            } else if (tag == 3){
                weakSelf.realtimeTranslateView.translateProvider = thirdPartyServiceProvider;
            }
            if (thirdPartyServiceProvider == ZegoRTServiceProviderGoogle) {
                [ZegoHudManager showMessage:@"谷歌在国内环境不稳定，切换到海外环境"];
            }
        };
        
        UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:listVc];
        nav.modalPresentationStyle = UIModalPresentationFullScreen;
        [self presentViewController:nav animated:YES completion:nil];
    }
}

- (void)startRealtimeSpeech:(BOOL)isOpen {
    self.selectLanguageFileBtn.enabled = !isOpen;
    if (!isOpen) {
        [[PCMFilePlayer sharePlayer] AudioQueueStop];
        [self.realtimeTranslation stopRealtimeTranslation];
        return;
    }
    ZegoRTServiceProvider speechProvider = self.realtimeTranslateView.speechProvider;
    ZegoRTServiceProvider translateProvider = self.realtimeTranslateView.translateProvider;
    ZegoSpeechLanguage sourceLanguage = self.realtimeTranslateView.sourceLanguage;
    ZegoTranslationLanguage targetLanguage = self.realtimeTranslateView.targetLanguage;
    BOOL enableTranslate = self.realtimeTranslateView.openTranslate;
    BOOL enableInterimTranslation = self.realtimeTranslateView.openMiddleResult;
    
    self.realtimeTranslation.speechToTextService = speechProvider;
    self.realtimeTranslation.textTranslationService = translateProvider;
    self.realtimeTranslation.sourceSpeechLanguage = sourceLanguage;
    self.realtimeTranslation.targetTranslationLanguage = targetLanguage;
    self.realtimeTranslation.enableTranslate = enableTranslate;
    self.realtimeTranslation.enableIntermediaTranslate = enableInterimTranslation;
    self.realtimeTranslation.pgsFlashFreq = 5;
    self.realtimeTranslation.serviceProviderRegion = ZegoRTServiceProviderRegionChineseMainland;
    
    // 开启实时传译服务
    int ret = [self.realtimeTranslation startRealtimeTranslation];
    if (ret != ZegoRealtimeTranslationErrorSuccess) {
        [self showErrorMessage:ret];
    }
    
//    [self.view makeToast:@"实时转译体验时长为2分钟" duration:1.5 position:CSToastPositionCenter];
//    // 开启成功后，定义2min，到达2min钟后，退出房间
//    dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(1.0 * MAX_REALTIME_TRANSLATE_TIME * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
//        if (![ZegoRealtimeTranslation getInstance].isStartRealtimeTranslation) {
//            return;
//        }
//
//        [self.navigationController.view makeToast:@"实时转译体验时长已到期" duration:1.5 position:CSToastPositionCenter];
//        [self backAction];
//    });
        
    [RTCEngineManager sharedManager].isSpeechAudioFile = self.isSelectAudioFile;
    if (self.isSelectAudioFile) {
//        [self.view makeToast:@"3s后开始发送音频数据" duration:1.5 position:CSToastPositionCenter];
        dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(1.0 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
            // 如果在发送数据之前，关闭掉实时语音识别服务，则不进行数据发送以及音频播放
            if (![ZegoRealtimeTranslation getInstance].isStartRealtimeTranslation) {
                return;
            }
            // 使用播放器播放语音文件
            [[PCMFilePlayer sharePlayer] player:self.pcmFilePath];
            __weak typeof(self) weakSelf = self;
            NSData *pcmFileData = [NSData dataWithContentsOfFile:self.pcmFilePath];
            NSLog(@"---音频文件大小为: %ld", self.pcmFileData.length);
            [self.realtimeTranslation startSpeechForAudioFile:pcmFileData handler:^(BOOL isFinish) {
                if (isFinish) {
                    // 数据发送完成后停止播放语音文件
                    [[PCMFilePlayer sharePlayer] AudioQueueStop];
                    dispatch_async(dispatch_get_main_queue(), ^{
                        [weakSelf showAlertController:@"提示" message:@"音频文件已经全部识别完成" handler:^{
                        }];
                        [weakSelf.realtimeTranslation stopRealtimeTranslation];
                    });
                }
            }];
        });
    }
}

#pragma mark - TextTranslate
- (void)textTranslateSet:(NSInteger)index {
    if (index == 0 || index == 1) {
        ZegoLanguageListViewController *languageVc = [ZegoLanguageListViewController new];
        languageVc.isSpeech = NO;
        languageVc.isTextTranslation = YES;
        languageVc.langDataSource = self;
        if (index == 0) { // 源语音
            languageVc.translateLanguage = self.textTranslateView.sourceLanguage;
        }else{   // 目标语言
            languageVc.translateLanguage = self.textTranslateView.targetLanguage;
        }
        
        __weak typeof(self) weakSelf = self;
        languageVc.selectTranslateLanguageBlock = ^(ZegoTransLanguageModel * _Nonnull translateModel) {
            if (index == 0) {
                weakSelf.textTranslateView.sourceLanguage = translateModel.language;
            }else{
                weakSelf.textTranslateView.targetLanguage = translateModel.language;
            }
        };
        
        UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:languageVc];
        nav.modalPresentationStyle = UIModalPresentationFullScreen;
        [self presentViewController:nav animated:YES completion:nil];
    }else{
        ZegoListViewController *listVc = [ZegoListViewController new];
        // 翻译服务供应商
        listVc.service = self.textTranslateView.translateProvider;
    
        __weak typeof(self) weakSelf = self;
       
        listVc.selectedSDKBlock = ^(ZegoRTServiceProvider thirdPartyServiceProvider) {
            weakSelf.textTranslateView.translateProvider = thirdPartyServiceProvider;
        };
        
        UINavigationController *nav = [[UINavigationController alloc] initWithRootViewController:listVc];
        nav.modalPresentationStyle = UIModalPresentationFullScreen;
        [self presentViewController:nav animated:YES completion:nil];

    }
}

- (void)startTranslate:(NSString *)inputText {
    self.textTranslateView.translateText = @"";  // 先把翻译结果显示框清空
    ZegoRTServiceProvider translateProvider = self.textTranslateView.translateProvider;
    ZegoTranslationLanguage sourceLanguage = self.textTranslateView.sourceLanguage;
    ZegoTranslationLanguage targetLanguage = self.textTranslateView.targetLanguage;
    self.textTranslateView.elapseTime = @"";
    NSTimeInterval startTime = [[NSDate date] timeIntervalSince1970]*1000;
    UIActivityIndicatorView *testActivityIndicator = [[UIActivityIndicatorView alloc]initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleWhiteLarge];
    testActivityIndicator.center = CGPointMake(SCREEN_SIZE.width/2.0, SCREEN_SIZE.height/2.0);//只能设置中心，不能设置大小
    [self.view addSubview:testActivityIndicator];
    [testActivityIndicator startAnimating]; // 开始旋转
    __weak typeof(self) weakSelf = self;
    [self.realtimeTranslation translate:inputText serviceProvider:translateProvider fromLanguage:sourceLanguage toLanguage:targetLanguage callback:^(int errorCode, NSString * _Nullable resultText) {
        [testActivityIndicator stopAnimating]; // 结束旋转
        [testActivityIndicator removeFromSuperview];
        
        NSTimeInterval elapseTime = [[NSDate date] timeIntervalSince1970]*1000 - startTime;
        weakSelf.textTranslateView.elapseTime = [NSString stringWithFormat:@"%.0fms", elapseTime];
        if (errorCode != 0) {
            if (errorCode == ZegoRealtimeTranslationErrorTranslateServiceLicenseFailed) {
                [weakSelf showAlertController:@"提示" message:@"翻译的服务未授权或已过期" handler:nil];
            }else if (errorCode == ZegoRealtimeTranslationErrorBadLanguagePair) {
                [weakSelf showAlertController:@"提示" message:[NSString stringWithFormat:@"源语言与目标语言不能设置成一样：%d", errorCode] handler:nil];
            }
            else if (errorCode == ZegoRealtimeTranslationErrorWrongTranslateRequest) {
                [weakSelf showAlertController:@"提示" message:@"输入的文本过长" handler:nil];
            }
            else if (errorCode == ZegoRealtimeTranslationErrorRequestTimeout) {
                [weakSelf showAlertController:@"提示" message:@"请求超时" handler:nil];
            }else{
                [weakSelf showAlertController:@"提示" message:[NSString stringWithFormat:@"文本翻译出错：%d", errorCode] handler:nil];
            }
            return;
        } else {
            weakSelf.textTranslateView.translateText = resultText;
        }
    }];
}

#pragma mark - ZegoLanguageListDataSource
- (NSArray<ZegoSpeechLanguageModel *> *)loadSpeechLanguageList {
    return self.realtimeTranslateView.speechLanguages;
}

- (NSArray<ZegoTransLanguageModel *> *)loadTransLanguageListIsTextTranslation:(BOOL)isTextTranslation {
    if (isTextTranslation) {
        return self.textTranslateView.transLanguages;
    } else {
        return self.realtimeTranslateView.transLanguages;
    }
}

#pragma mark - UIDocumentInteractionControllerDelegate
//必须实现的代理方法 预览窗口以模式窗口的形式显示，因此需要在该方法中返回一个view controller ，作为预览窗口的父窗口。如果你不实现该方法，或者在该方法中返回 nil，或者你返回的 view controller 无法呈现模式窗口，则该预览窗口不会显示。
- (UIViewController *)documentInteractionControllerViewControllerForPreview:(UIDocumentInteractionController *)controller{
    
    return self;
}

- (UIView*)documentInteractionControllerViewForPreview:(UIDocumentInteractionController*)controller {
    
    return self.view;
}

- (CGRect)documentInteractionControllerRectForPreview:(UIDocumentInteractionController*)controller {
    
    return CGRectMake(0, 0, self.view.bounds.size.width, self.view.bounds.size.height);
}

#pragma mark - SPAlertControllerDelegate
- (void)didDismissAlertController:(SPAlertController *)alertController {
    [self backAction];
}

#pragma mark - Private
- (NSString *)getDeviceModel {
    struct utsname systemInfo;
    uname(&systemInfo);
    return [NSString stringWithCString:systemInfo.machine encoding:NSASCIIStringEncoding];
}

- (void)showAlertController:(NSString *)title message:(NSString *)message handler:(void(^)(void))handler {
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:title message:message preferredStyle:UIAlertControllerStyleAlert];
    UIAlertAction *confirmAction = [UIAlertAction actionWithTitle:@"确定" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
        if (handler) {
            handler();
        }
    }];
    [alertController addAction:confirmAction];
    [self presentViewController:alertController animated:YES completion:nil];
}

- (UIButton *)makeupCheckButtonWithTitle:(NSString *)title {
    UIButton *button = [[UIButton alloc] init];
    [button setTitle:title forState:UIControlStateNormal];
    [button setImage:[UIImage imageNamed:@"circle_unselect"] forState:UIControlStateNormal];
    [button setImage:[UIImage imageNamed:@"circle_select"] forState:UIControlStateSelected];
    [button setTitleColor:LCColor(51, 51, 51) forState:UIControlStateNormal];
    button.titleLabel.font = [UIFont systemFontOfSize:13];
    return button;
}

- (UITextView *)makeupShowTextView {
    UITextView *textView = [[UITextView alloc] init];
    textView.editable = NO;
    textView.backgroundColor = LCColor(66, 148, 178);
    textView.textColor = [UIColor blackColor];
    textView.font = [UIFont systemFontOfSize:13];
    return textView;
}

- (CGFloat)previerViewHeight {
    CGFloat screenWidth = SCREEN_SIZE.width;
    return screenWidth/(16.0/9.0);
}

- (void)showErrorMessage:(int)errorCode {
    switch (errorCode) {
        case ZegoRealtimeTranslationErrorInvalidLicence: // 许可证无效
            [ZegoHudManager showMessage:@"license无效"];
            break;
        case ZegoRealtimeTranslationErrorLicenseExpired:
            [ZegoHudManager showMessage:@"license过期"];
            break;
        case ZegoRealtimeTranslationErrorInvalidPackageName:
            [ZegoHudManager showMessage:@"包名无效"];
            break;
        case ZegoRealtimeTranslationErrorBadLanguagePair:
            [ZegoHudManager showMessage:@"源语言与目标语言不能设置成一样"];
            break;
        case ZegoRealtimeTranslationErrorSpeechLanguageNotSuport:
            [ZegoHudManager showMessage:@"语音识别的语言不支持"];
            break;
        case ZegoRealtimeTranslationErrorNoNetwork:
            [ZegoHudManager showMessage:@"没有网络"];
            break;
        case ZegoRealtimeTranslationErrorNetworkError:
            [ZegoHudManager showMessage:@"网络出错"];
            break;
        case ZegoRealtimeTranslationErrorRequestTimeout:
            [ZegoHudManager showMessage:@"请求超时"];
            break;
        case ZegoRealtimeTranslationErrorInvalidAccount:
            [ZegoHudManager showMessage:@"账号无效"];
            break;
        case ZegoRealtimeTranslationErrorQuotaExceeded:
            [ZegoHudManager showMessage:@"额度已用完"];
            break;
        case ZegoRealtimeTranslationErrorUnkownError:
            [ZegoHudManager showMessage:@"未知错误"];
            break;
        case ZegoRealtimeTranslationErrorWrongRequest:
            [ZegoHudManager showMessage:@"翻译请求错误"];
            break;
        case ZegoRealtimeTranslationErrorTranslateServiceLicenseFailed:
            [ZegoHudManager showMessage:@"翻译的服务未授权或已过期"];
            break;
        case ZegoRealtimeTranslationErrorSpeechToTextServiceLicenseFailed:
            [ZegoHudManager showMessage:@"语音识别的服务未授权或已过期"];
            break;
//        case ZegoRealtimeTranslationErrorTranslateParmterError:
//            [ZegoHudManager showMessage:@"文本翻译语言参数设置错误"];
//            break;
        case ZegoRealtimeTranslationErrorSourceLanguageCannotTranslateToTargetLanguage:
            [ZegoHudManager showMessage:@"不支持源语言与目标语言的互译"];
            break;
        default:
            [ZegoHudManager showMessage:[@"startRealtimeTranslate failed:" stringByAppendingFormat:@"%d", errorCode]];
            break;
    }
}

#pragma mark - property
- (UIView *)localPreviewView {
    if (!_localPreviewView) {
        _localPreviewView = [[UIView alloc] init];
        _localPreviewView.backgroundColor = [UIColor lightGrayColor];
    }
    return _localPreviewView;
}

- (UIView *)remotePreviewView {
    if (!_remotePreviewView) {
        _remotePreviewView = [[UIView alloc] init];
        _remotePreviewView.backgroundColor = [UIColor lightGrayColor];
    }
    return _remotePreviewView;
}

- (UILabel *)localUserNameLab {
    if (!_localUserNameLab) {
        _localUserNameLab = [[UILabel alloc] init];
        _localUserNameLab.font = [UIFont systemFontOfSize:13];
        _localUserNameLab.textColor = [UIColor whiteColor];
        _localUserNameLab.textAlignment = NSTextAlignmentRight;
    }
    return _localUserNameLab;
}

- (UILabel *)remoteUserNameLab {
    if (!_remoteUserNameLab) {
        _remoteUserNameLab = [[UILabel alloc] init];
        _remoteUserNameLab.font = [UIFont systemFontOfSize:13];
        _remoteUserNameLab.textColor = [UIColor whiteColor];
        _remoteUserNameLab.textAlignment = NSTextAlignmentRight;
    }
    return _remoteUserNameLab;
}

- (ZegoTabChangeView *)tabChangeView {
    if (!_tabChangeView) {
        _tabChangeView = [[ZegoTabChangeView alloc] init];
        __weak typeof(self) weakSelf = self;
        _tabChangeView.tabChangedBlock = ^(BOOL isRealTimeTranslate) {
            weakSelf.realtimeTranslateView.hidden = !isRealTimeTranslate;
            weakSelf.textTranslateView.hidden = isRealTimeTranslate;
        };
    }
    return _tabChangeView;
}

- (UIButton *)selectLanguageFileBtn {
    if (!_selectLanguageFileBtn) {
        _selectLanguageFileBtn = [[UIButton alloc] init];
        [_selectLanguageFileBtn setTitle:@"选择音频文件" forState:UIControlStateNormal];
        [_selectLanguageFileBtn setTitleColor:[UIColor blueColor] forState:UIControlStateNormal];
        [_selectLanguageFileBtn setTitleColor:LCColor(153, 153, 153) forState:UIControlStateDisabled];
        _selectLanguageFileBtn.titleLabel.font = [UIFont systemFontOfSize:13.0f];
        [_selectLanguageFileBtn addTarget:self action:@selector(selectLanguageFileBtnClicked:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _selectLanguageFileBtn;
}

- (ZegoRealtimeTranslateView *)realtimeTranslateView {
    if (!_realtimeTranslateView) {
        _realtimeTranslateView = [[ZegoRealtimeTranslateView alloc] init];
        _realtimeTranslateView.hidden = NO;
        _realtimeTranslateView.speechProvider = ZegoRTServiceProviderIflytek;
        _realtimeTranslateView.translateProvider = ZegoRTServiceProviderIflytek;
        _realtimeTranslateView.sourceLanguage = ZegoSpeechLanguageZH_CN;
        _realtimeTranslateView.targetLanguage = ZegoTranslationLanguageEN;
        _realtimeTranslateView.openTranslate = YES;
        _realtimeTranslateView.openMiddleResult = YES;
        __weak typeof(self) weakSelf = self;
        _realtimeTranslateView.realtimeTranslateSetItemBlock = ^(NSInteger index) {
            [weakSelf realtimeTranslateSet:index];
        };
        
        _realtimeTranslateView.startSpeechBlock = ^(BOOL isSelected) {
            [weakSelf startRealtimeSpeech:isSelected];
        };
        
        _realtimeTranslateView.clearScreenBlock = ^{
            // 清屏需要清除掉缓存的结果
            weakSelf.translateResult = [NSMutableString new];
            weakSelf.recogizedResult = [NSMutableString new];
            
            [weakSelf resetData];
        };
    }
    return _realtimeTranslateView;
}

- (ZegoTextTranslateView *)textTranslateView {
    if (!_textTranslateView) {
        _textTranslateView = [[ZegoTextTranslateView alloc] init];
        _textTranslateView.hidden = YES;
        _textTranslateView.translateProvider = ZegoRTServiceProviderIflytek;
        _textTranslateView.sourceLanguage = ZegoTranslationLanguageZH_HANS;
        _textTranslateView.targetLanguage = ZegoTranslationLanguageEN;
        __weak typeof(self) weakSelf = self;
        _textTranslateView.textTranslateSetItemBlock = ^(NSInteger index) {
            [weakSelf textTranslateSet:index];
        };
        _textTranslateView.startTranslateBlock = ^(NSString * _Nonnull inputText) {
            [weakSelf startTranslate:inputText];
        };
    }
    return _textTranslateView;
}

- (NSMutableArray<NSString *> *)recognizeList {
    if (!_recognizeList) {
        _recognizeList = [NSMutableArray arrayWithArray:@[@""]];
    }
    return _recognizeList;
}

- (NSMutableArray<NSString *> *)translateList {
    if (!_translateList) {
        _translateList = [NSMutableArray arrayWithArray:@[@""]];
    }
    return _translateList;
}

@end
