//
//  RTCEngineManager.h
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/10/28.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "IRTCEventListener.h"
#import "ExpressProxy.h"
#import "ZegoSteamInfo.h"
NS_ASSUME_NONNULL_BEGIN

UIKIT_EXTERN NSString * const STREAM_PREFIX;

@interface RTCEngineManager : NSObject
@property (nonatomic, assign, readonly) BOOL isInRoom;  // 是否在房间
// 流信息列表
@property (nonatomic, strong, readonly) NSMutableArray<ZegoSteamInfo *> *streamInfoList;
@property (nonatomic, copy, readonly) NSString *publishStreamID;   // 推流的流ID
@property (nonatomic, assign) BOOL isSpeechAudioFile;
- (instancetype)init NS_UNAVAILABLE;
+ (instancetype)new NS_UNAVAILABLE;
+ (instancetype)sharedManager;
// 初始化rtc
- (void)initRtc;
// 反初始化rtc
- (void)unInitRtc:(void(^)(void))callback;
// 登录房间
- (void)loginRoom:(NSString *)roomID roomName:(NSString *)roomName userID:(NSString *)userID userName:(NSString *)userName callback:(void(^)(int errorCode, NSDictionary *extendedData))callback;
/// 登出房间
/// - Parameter roomID: 房间ID
- (void)logoutRoom:(NSString *)roomID;
/// 登出房间 - 用户所在的所有房间
- (void)logoutRoom;
// 开始推流
- (void)startPublishStream:(NSString *)streamID;
// 停止推流
- (void)stopPublishStream;
/// 开始拉流
/// - Parameters:
///   - streamID: 流ID
///   - view: 预览视图
- (void)startPlayingStream:(NSString *)streamID view:(UIView *)view;
/// 停止拉流
/// - Parameter streamID: 流ID
- (void)stopPlayingStream:(NSString *)streamID;
// 开始推流，流ID按约定的模式拼接而成
- (void)startPublishStream;
- (void)startPreview:(UIView *)view;
- (void)sendSEIData:(NSData *)data;
- (void)sendRecognizingText:(NSString *)text;
- (void)sendRecognizedText:(NSString *)text;
- (void)addRTCEventListener:(id<IRTCEventListener>)listener;
- (void)removeRTCEventListener:(id<IRTCEventListener>)listener;
- (void)onStreamAdd:(NSArray<ZegoSteamInfo *> *)streamInfoList;
- (void)onStreamRemove:(NSArray<ZegoSteamInfo *> *)streamInfoList;
- (void)onReceiveSEI:(NSData *)data streamID:(NSString *)streamID;
- (void)onRoomStateChanged:(RTCEngineRoomStateChangedReason)reason;
- (void)onCapturedAudioData:(const unsigned char *)data dataLength:(unsigned int)dataLength;

@end

NS_ASSUME_NONNULL_END
