//
//  ZegoItemSelectView.m
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/10/26.
//

#import "ZegoItemSelectView.h"
#import "ZegoGlobalDefines.h"
#import <Masonry/Masonry.h>

@interface ZegoItemSelectView ()
@property (nonatomic, strong) UILabel *titleLab;
@property (nonatomic, strong) UIView *bgView;
@property (nonatomic, strong) UILabel *contentLab;
@property (nonatomic, strong) UIImageView *iconImgView;
@property (nonatomic, strong) UITextField *nameTextField;
@end

@implementation ZegoItemSelectView
#pragma mark - Property
- (UILabel *)titleLab {
    if (!_titleLab) {
        _titleLab = [[UILabel alloc] init];
        _titleLab.text = @"语音SDK";
        _titleLab.textColor = LCColor(153, 153, 153);
        _titleLab.font = [UIFont systemFontOfSize:13];
    }
    return _titleLab;
}

- (UIView *)bgView {
    if (!_bgView) {
        _bgView = [[UIView alloc] init];
        _bgView.backgroundColor = LCColor(246, 246, 246);
        _bgView.layer.cornerRadius = 4.0f;
        _bgView.layer.masksToBounds = YES;
    }
    return _bgView;
}

- (UILabel *)contentLab {
    if (!_contentLab) {
        _contentLab = [[UILabel alloc] init];
        _contentLab.text = @"微软";
        _contentLab.textColor = LCColor(51, 51, 51);
        _contentLab.font = [UIFont systemFontOfSize:13];
    }
    return _contentLab;
}

- (UITextField *)nameTextField {
    if (!_nameTextField) {
        _nameTextField = [[UITextField alloc] init];
        _nameTextField.textColor = LCColor(51, 51, 51);
        _nameTextField.font = [UIFont systemFontOfSize:13];
    }
    return _nameTextField;
}

- (UIImageView *)iconImgView {
    if (!_iconImgView) {
        _iconImgView = [[UIImageView alloc] init];
        _iconImgView.image = [UIImage imageNamed:@"select_down"];
    }
    return _iconImgView;
}

#pragma mark - LifeCycle
- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        [self addSubview:self.titleLab];
        [self addSubview:self.bgView];
        [self.bgView addSubview:self.contentLab];
        [self.bgView addSubview:self.iconImgView];
        [self.bgView addSubview:self.nameTextField];
        
        [self.titleLab mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(5);
            make.centerY.mas_equalTo(0);
            make.width.mas_equalTo(60);
            make.height.mas_equalTo(20);
        }];
        
        [self.bgView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.equalTo(self.titleLab.mas_right);
            make.centerY.right.mas_equalTo(0);
            make.height.mas_equalTo(28);
        }];
        
        [self.iconImgView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.right.mas_equalTo(-3);
            make.centerY.mas_equalTo(0);
            make.width.height.mas_equalTo(15);
        }];
        
        [self.contentLab mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(5);
            make.centerY.mas_equalTo(0);
            make.right.equalTo(self.iconImgView.mas_right).offset(-3);
            make.height.mas_equalTo(18);
        }];
        
        [self.nameTextField mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(5);
            make.centerY.mas_equalTo(0);
            make.right.equalTo(self.iconImgView.mas_right).offset(-3);
            make.height.mas_equalTo(18);
        }];
        
        self.contentLab.userInteractionEnabled = YES;
        UITapGestureRecognizer *tap = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(tapAction:)];
        [self.contentLab addGestureRecognizer:tap];
        
        [self.nameTextField addTarget:self action:@selector(textContentChanged:) forControlEvents:UIControlEventEditingChanged];
    }
    return self;
}

- (void)setTitle:(NSString *)title {
    _title = title;
    self.titleLab.text = title;
}

- (void)setContent:(NSString *)content {
    _content = content;
    self.nameTextField.hidden = YES;
    self.contentLab.text = content;
}

- (void)setUserName:(NSString *)userName {
    _userName = userName;
    self.contentLab.hidden = YES;
    self.nameTextField.text = userName;
}

- (void)tapAction:(UITapGestureRecognizer *)recognizer {
    if (self.itemSelectedBlock) {
        self.itemSelectedBlock();
    } 
}

- (void)setShowPull:(BOOL)showPull {
    _showPull = showPull;
    
    self.iconImgView.hidden = !showPull;
}

- (void)textContentChanged:(UITextField *)textField {
    NSString *content = textField.text;
    if (content.length > 20) {
        self.nameTextField.text = [content substringToIndex:20];
    }
}


/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/

@end
