//
//  ZegoRealtimeResultListView.m
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/12/6.
//

#import "ZegoRealtimeResultListView.h"
#import <Masonry/Masonry.h>
#import "ZegoGlobalDefines.h"
#import "UITableView+FDTemplateLayoutCell.h"
#import "ZegoRealtimTranslateListCell.h"
#import "ZegoHudManager.h"

@interface ZegoRealtimeResultListView ()<UITableViewDelegate, UITableViewDataSource>
@property (nonatomic, strong) UITableView *tableView;
@end

@implementation ZegoRealtimeResultListView
#pragma mark - LifeCycle
- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        [self addSubview:self.tableView];
        
        [self.tableView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.edges.mas_equalTo(0);
        }];
    }
    return self;
}

- (void)setDataSource:(NSMutableArray *)dataSource {
    _dataSource = dataSource;
    
    [self.tableView reloadData];
    NSInteger rows = [self.tableView numberOfRowsInSection:0];
    if (rows > 0) {
        NSIndexPath *indexPath = [NSIndexPath indexPathForRow:rows-1 inSection:0];
        [self.tableView scrollToRowAtIndexPath:indexPath atScrollPosition:UITableViewScrollPositionBottom animated:YES];
    }
}


#pragma mark - UITableViewDelegate & UITableViewDataSource
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.dataSource.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    ZegoRealtimTranslateListCell *cell = [tableView dequeueReusableCellWithIdentifier:@"RealtimeResultListCell"];
    NSString *result = [self.dataSource objectAtIndex:indexPath.row];
    cell.contentLab.text = result;
    __weak typeof(self) weakSelf = self;
    cell.longPressContentBlock = ^(NSString * _Nonnull content, CGRect rect) {
        UIPasteboard *pasteboard = [UIPasteboard generalPasteboard];
        pasteboard.string = [self.dataSource componentsJoinedByString:@"\n"];
        [ZegoHudManager showMessage:@"复制成功"];
    };
    return cell;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return [tableView fd_heightForCellWithIdentifier:@"RealtimeResultListCell" configuration:^(ZegoRealtimTranslateListCell *cell) {
        NSString *result = [self.dataSource objectAtIndex:indexPath.row];
        cell.contentLab.text = result;
    }];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    
}

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/

#pragma mark - Property
- (UITableView *)tableView {
    if (!_tableView) {
        _tableView = [[UITableView alloc] initWithFrame:CGRectZero style:UITableViewStylePlain];
        _tableView.delegate = self;
        _tableView.dataSource = self;
        _tableView.backgroundColor = [UIColor whiteColor];
        _tableView.separatorStyle = UITableViewCellSeparatorStyleNone;
        [_tableView registerClass:ZegoRealtimTranslateListCell.class forCellReuseIdentifier:@"RealtimeResultListCell"];
        _tableView.tableFooterView = [UIView new];
    }
    return _tableView;
}

@end
