//
//  ZegoRealtimeTranslateView.m
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/11/5.
//

#import "ZegoRealtimeTranslateView.h"
#import "ZegoGlobalDefines.h"
#import <Masonry/Masonry.h>
#import "ZegoSetTableViewCell.h"
#import "ZegoSdkConfig.h"
#import "ZegoRealtimeResultListView.h"
#import "ZegoLanguageSupport.h"

@interface ZegoRealtimeTranslateView ()<UITableViewDelegate, UITableViewDataSource>
@property (nonatomic, strong) UITextView *recognizeTextView;
@property (nonatomic, strong) UITextView *translateTextView;
@property (nonatomic, strong) UILabel *recognizePlaceholderLab;
@property (nonatomic, strong) UILabel *translatePlaceholderLab;
@property (nonatomic, strong) UIButton *clearBtn;
@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, strong) UIButton *speechBtn;
@property (nonatomic, strong) UILabel *setLab;
@property (nonatomic, strong) NSArray<NSString *> *dataSource;
@property (nonatomic, assign) BOOL isStartSpeech;   // 正在识别中
@property (nonatomic, strong) ZegoRealtimeResultListView *recognizeResultListView;
@property (nonatomic, strong) ZegoRealtimeResultListView *translateResultListView;
@property (nonatomic, strong) NSMutableDictionary<NSString *, ZegoSpeechLanguageModel *> *speechLanguageDict;
@property (nonatomic, strong) NSMutableDictionary<NSString *, ZegoTransLanguageModel *> *transLanguageDict;
@end

@implementation ZegoRealtimeTranslateView
#pragma mark - LifeCycle
- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        [self addSubview:self.recognizeTextView];
        [self addSubview:self.translateTextView];
        [self addSubview:self.recognizePlaceholderLab];
        [self addSubview:self.translatePlaceholderLab];
        [self addSubview:self.clearBtn];
        [self addSubview:self.setLab];
        [self addSubview:self.speechBtn];
        [self addSubview:self.tableView];
        [self addSubview:self.recognizeResultListView];
        [self addSubview:self.translateResultListView];
        
        [self.recognizeTextView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(10);
            make.right.mas_equalTo(-10);
            make.top.mas_equalTo(0);
            make.height.mas_equalTo(80);
        }];
        
        [self.recognizeResultListView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(10);
            make.right.mas_equalTo(-10);
            make.top.mas_equalTo(0);
            make.height.mas_equalTo(80);
        }];
        
        [self.translateTextView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.top.equalTo(self.recognizeTextView.mas_bottom).offset(2);
            make.left.mas_equalTo(10);
            make.right.mas_equalTo(-10);
            make.height.mas_equalTo(80);
        }];
        
        [self.translateResultListView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.top.equalTo(self.recognizeTextView.mas_bottom).offset(2);
            make.left.mas_equalTo(10);
            make.right.mas_equalTo(-10);
            make.height.mas_equalTo(80);
        }];
        
        [self.recognizePlaceholderLab mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.equalTo(self.recognizeTextView.mas_left).offset(5);
            make.top.equalTo(self.recognizeTextView.mas_top).offset(5);
        }];
        
        [self.translatePlaceholderLab mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.equalTo(self.translateTextView.mas_left).offset(5);
            make.top.equalTo(self.translateTextView.mas_top).offset(5);
        }];
        
        [self.clearBtn mas_makeConstraints:^(MASConstraintMaker *make) {
            make.right.mas_equalTo(-20);
            make.width.mas_equalTo(70);
            make.height.mas_equalTo(30);
            make.top.equalTo(self.translateTextView.mas_bottom).offset(10);
        }];
        
        [self.setLab mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(10);
            make.top.equalTo(self.clearBtn.mas_bottom);
        }];
        
        [self.speechBtn mas_makeConstraints:^(MASConstraintMaker *make) {
            make.width.mas_equalTo(180);
            make.height.mas_equalTo(40);
            make.bottom.mas_equalTo(-20);
            make.centerX.mas_equalTo(0);
        }];
        
        [self.tableView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.right.mas_equalTo(0);
            make.bottom.equalTo(self.speechBtn.mas_top);
            make.top.equalTo(self.setLab.mas_bottom).offset(0);
        }];
    }
    return self;
}

- (void)setRecognizedTextList:(NSMutableArray<NSString *> *)recognizedTextList {
    _recognizedTextList = recognizedTextList;
    
    self.recognizeResultListView.dataSource = recognizedTextList;
}

- (void)setTranslateTextList:(NSMutableArray<NSString *> *)translateTextList {
    _translateTextList = translateTextList;
    
    self.translateResultListView.dataSource = translateTextList;
}

#pragma mark - Action
- (void)clearBtnClicked:(UIButton *)sender {
    self.recognizeTextView.text = @"";
    self.translateTextView.text = @"";
    self.recognizePlaceholderLab.hidden = NO;
    self.translatePlaceholderLab.hidden = NO;
    if (self.clearScreenBlock) {
        self.clearScreenBlock();
    } 
}

- (void)speechBtnClicked:(UIButton *)sender {
    sender.selected = !sender.selected;
    self.isStartSpeech = sender.selected;
    if (self.startSpeechBlock) {
        self.startSpeechBlock(sender.selected);
    }
    [self.tableView reloadData];
}

#pragma mark - Set
- (void)setSourceLanguage:(ZegoSpeechLanguage)sourceLanguage {
    _sourceLanguage = sourceLanguage;
    [self.tableView reloadData];
}

- (void)setTargetLanguage:(ZegoTranslationLanguage)targetLanguage {
    _targetLanguage = targetLanguage;
    [self.tableView reloadData];
}

- (void)setSpeechProvider:(ZegoRTServiceProvider)speechProvider {
    _speechProvider = speechProvider;
    
//    ZegoSpeechLanguageSuportModel *model = [[ZegoSdkConfig config].speechLanguageSupportModels objectAtIndex:self.sourceLanguage];
//    if ((speechProvider == ZegoRTServiceProviderGoogle && !model.google_suport)
//        || (speechProvider == ZegoRTServiceProviderIflytek && !model.ifly_suport)) {
//        self.sourceLanguage = ZegoSpeechLanguageZH_CN;
//    }
    
    if (speechProvider == ZegoRTServiceProviderGoogle) {
        self.speechLanguages = [ZegoLanguageSupport getGoogleSttLanguages];
    } else if (speechProvider == ZegoRTServiceProviderIflytek) {
        self.speechLanguages = [ZegoLanguageSupport getIflySttLanguages];
    } else if (speechProvider == ZegoRTServiceProviderLiveData) {
        self.speechLanguages = [ZegoLanguageSupport getLiveDataSttLanguages];
    }
    
    [self.speechLanguageDict removeAllObjects];
    for (ZegoSpeechLanguageModel *model in self.speechLanguages) {
        [self.speechLanguageDict setObject:model forKey:@(model.language).stringValue];
    }
    
    BOOL hasSourceLang = [self.speechLanguageDict.allKeys containsObject:@(self.sourceLanguage).stringValue];
    if (!hasSourceLang) {
        self.sourceLanguage = ZegoSpeechLanguageZH_CN;
    }
    
    [self.tableView reloadData];
}

- (void)setTranslateProvider:(ZegoRTServiceProvider)translateProvider {
    _translateProvider = translateProvider;
    
    if (translateProvider == ZegoRTServiceProviderGoogle) {
        self.transLanguages = [ZegoLanguageSupport getGoogleTransLanguages];
    } else if (translateProvider == ZegoRTServiceProviderIflytek) {
        self.transLanguages = [ZegoLanguageSupport getIflyTransLanguages];
    } else if (translateProvider == ZegoRTServiceProviderLiveData) {
        self.transLanguages = [ZegoLanguageSupport getLiveDataTransLanguages];
    }
    
    [self.transLanguageDict removeAllObjects];
    for (ZegoTransLanguageModel *model in self.transLanguages) {
        [self.transLanguageDict setObject:model forKey:@(model.language).stringValue];
    }
    
    BOOL hasTargetLang = [self.transLanguageDict.allKeys containsObject:@(self.targetLanguage).stringValue];
    if (!hasTargetLang) {
        self.targetLanguage = ZegoTranslationLanguageEN;
    }
    
    [self.tableView reloadData];
}

- (void)setOpenTranslate:(BOOL)openTranslate {
    _openTranslate = openTranslate;
    [self.tableView reloadData];
}

- (void)setOpenMiddleResult:(BOOL)openMiddleResult {
    _openMiddleResult = openMiddleResult;
    [self.tableView reloadData];
}

- (void)setRecognizeText:(NSString *)recognizeText {
    _recognizeText = recognizeText;
    self.recognizePlaceholderLab.hidden = recognizeText.length > 0;
    self.recognizeTextView.text = recognizeText;
    [self.recognizeTextView scrollRangeToVisible:NSMakeRange(self.recognizeTextView.text.length,1)];
}

- (void)setTranslateText:(NSString *)translateText {
    _translateText = translateText;
    self.translatePlaceholderLab.hidden = translateText.length > 0;
    self.translateTextView.text = translateText;
    [self.translateTextView scrollRangeToVisible:NSMakeRange(self.translateTextView.text.length,1)];
}

- (void)refreshUIByUserRole:(BOOL)isHost {
    if (isHost) {
        self.tableView.hidden = NO;
        self.speechBtn.hidden = NO;
        self.setLab.hidden = NO;
    } else {
        self.tableView.hidden = YES;
        self.speechBtn.hidden = YES;
        self.setLab.hidden = YES;
    }
}

#pragma mark - UITableViewDelegate & UITableViewDataSource
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    if (self.openTranslate) {
        return self.dataSource.count;
    }else{
        return self.dataSource.count-1;
    }
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    ZegoSetTableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:NSStringFromClass(ZegoSetTableViewCell.class)];
    cell.titleLab.text = self.dataSource[indexPath.row];
    cell.disableEdit = self.isStartSpeech;
    if (indexPath.row == 4 || indexPath.row == 5) {
        cell.sw.hidden = NO;
        cell.contentLab.text = @"";
        cell.accessoryType = UITableViewCellAccessoryNone;
        if (indexPath.row == 4) {
            cell.sw.on = self.openTranslate;
        }else if (indexPath.row == 5) {
            cell.sw.on = self.openMiddleResult;
        }
        __weak typeof(self) weakSelf = self;
        cell.switchValueChangedBlock = ^(BOOL isOpen) {
            if (indexPath.row == 4) {
                weakSelf.openTranslate = isOpen;
            }else if (indexPath.row == 5) {
                weakSelf.openMiddleResult = isOpen;
            }
            [weakSelf.tableView reloadData];
        };
    }else{
        cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
        cell.sw.hidden = YES;
        switch (indexPath.row) {
            case 0:
            {
                ZegoSpeechLanguageModel *model = [self.speechLanguageDict objectForKey:@(self.sourceLanguage).stringValue];
                cell.contentLab.text = model.language_name;
            }
                break;
            case 1:
            {
                ZegoTransLanguageModel *model = [self.transLanguageDict objectForKey:@(self.targetLanguage).stringValue];
                cell.contentLab.text = model.language_name;
            }
                break;
            case 2:
                cell.contentLab.text = [[ZegoSdkConfig config] getThirdServiceProviderName:self.speechProvider];
                break;
            case 3:
                cell.contentLab.text = [[ZegoSdkConfig config] getThirdServiceProviderName:self.translateProvider];
                break;
            default:
                break;
        }
    }
    cell.selectionStyle = UITableViewCellSelectionStyleNone;
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    if (indexPath.row == 4 || indexPath.row == 5) {
        return;
    }
    
    if (self.isStartSpeech) {
        return;
    }
    
    if (self.realtimeTranslateSetItemBlock) {
        self.realtimeTranslateSetItemBlock(indexPath.row);
    }
}

#pragma mark - Private
- (UITextView *)makeupShowTextView {
    UITextView *textView = [[UITextView alloc] init];
    textView.editable = NO;
    textView.textColor = LCColor(51, 51, 51);
    textView.font = [UIFont systemFontOfSize:13];
    textView.layer.cornerRadius = 2.0f;
    textView.clipsToBounds = YES;
    textView.layer.borderColor = LCColor(51, 51, 51).CGColor;
    textView.layer.borderWidth = 1.0f;
    return textView;
}

#pragma mark - Property
- (NSArray<ZegoSpeechLanguageModel *> *)speechLanguages {
    if (!_speechLanguages) {
        _speechLanguages = [NSArray array];
    }
    return _speechLanguages;
}

- (NSArray<ZegoTransLanguageModel *> *)transLanguages {
    if (!_transLanguages) {
        _transLanguages = [NSArray array];
    }
    return _transLanguages;
}

- (NSMutableDictionary<NSString *,ZegoSpeechLanguageModel *> *)speechLanguageDict {
    if (!_speechLanguageDict) {
        _speechLanguageDict = [NSMutableDictionary dictionary];
    }
    return _speechLanguageDict;
}

- (NSMutableDictionary<NSString *,ZegoTransLanguageModel *> *)transLanguageDict {
    if (!_transLanguageDict) {
        _transLanguageDict = [NSMutableDictionary dictionary];
    }
    return _transLanguageDict;
}

- (UITextView *)recognizeTextView {
    if (!_recognizeTextView) {
        _recognizeTextView = [self makeupShowTextView];
    }
    return _recognizeTextView;
}

- (UITextView *)translateTextView {
    if (!_translateTextView) {
        _translateTextView = [self makeupShowTextView];
    }
    return _translateTextView;
}

- (ZegoRealtimeResultListView *)recognizeResultListView {
    if (!_recognizeResultListView) {
        _recognizeResultListView = [[ZegoRealtimeResultListView alloc] init];
        _recognizeResultListView.layer.cornerRadius = 2.0f;
        _recognizeResultListView.clipsToBounds = YES;
        _recognizeResultListView.layer.borderColor = LCColor(51, 51, 51).CGColor;
        _recognizeResultListView.layer.borderWidth = 1.0f;
    }
    return _recognizeResultListView;
}

- (ZegoRealtimeResultListView *)translateResultListView {
    if (!_translateResultListView) {
        _translateResultListView = [[ZegoRealtimeResultListView alloc] init];
        _translateResultListView.layer.cornerRadius = 2.0f;
        _translateResultListView.clipsToBounds = YES;
        _translateResultListView.layer.borderColor = LCColor(51, 51, 51).CGColor;
        _translateResultListView.layer.borderWidth = 1.0f;
    }
    return _translateResultListView;
}

- (UILabel *)recognizePlaceholderLab {
    if (!_recognizePlaceholderLab) {
        _recognizePlaceholderLab = [[UILabel alloc] init];
        _recognizePlaceholderLab.text = @"实时语音识别结果";
        _recognizePlaceholderLab.font = [UIFont systemFontOfSize:13];
        _recognizePlaceholderLab.textColor = LCColor(153, 153, 153);
    }
    return _recognizePlaceholderLab;
}

- (UILabel *)translatePlaceholderLab {
    if (!_translatePlaceholderLab) {
        _translatePlaceholderLab = [[UILabel alloc] init];
        _translatePlaceholderLab.text = @"语音识别文本翻译结果";
        _translatePlaceholderLab.font = [UIFont systemFontOfSize:13];
        _translatePlaceholderLab.textColor = LCColor(153, 153, 153);
    }
    return _translatePlaceholderLab;
}

- (UIButton *)clearBtn {
    if (!_clearBtn) {
        _clearBtn = [[UIButton alloc] init];
        [_clearBtn setTitle:@"清屏" forState:UIControlStateNormal];
        [_clearBtn setTitleColor:LCColor(51, 51, 51) forState:UIControlStateNormal];
        _clearBtn.titleLabel.font = [UIFont systemFontOfSize:13];
        _clearBtn.layer.cornerRadius = 4.0f;
        _clearBtn.clipsToBounds = YES;
        _clearBtn.layer.borderColor = LCColor(51, 51, 51).CGColor;
        _clearBtn.layer.borderWidth = 1.0f;
        [_clearBtn addTarget:self action:@selector(clearBtnClicked:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _clearBtn;
}

- (UILabel *)setLab {
    if (!_setLab) {
        _setLab = [[UILabel alloc] init];
        _setLab.text = @"设置";
        _setLab.font = [UIFont systemFontOfSize:18 weight:UIFontWeightBold];
        _setLab.textColor = [UIColor blackColor];
    }
    return _setLab;
}

- (UIButton *)speechBtn {
    if (!_speechBtn) {
        _speechBtn = [[UIButton alloc] init];
        [_speechBtn setTitle:@"开启实时语音识别" forState:UIControlStateNormal];
        [_speechBtn setTitle:@"关闭实时语音识别" forState:UIControlStateSelected];
        [_speechBtn setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
        [_speechBtn setTitleColor:[UIColor whiteColor] forState:UIControlStateSelected];
        _speechBtn.backgroundColor = [UIColor blueColor];
        _speechBtn.titleLabel.font = [UIFont systemFontOfSize:15];
        _speechBtn.layer.cornerRadius = 4.0f;
        _speechBtn.clipsToBounds = YES;
        [_speechBtn addTarget:self action:@selector(speechBtnClicked:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _speechBtn;
}

- (UITableView *)tableView {
    if (!_tableView) {
        _tableView = [[UITableView alloc] initWithFrame:CGRectZero style:UITableViewStylePlain];
        _tableView.delegate = self;
        _tableView.dataSource = self;
        _tableView.rowHeight = 44.0;
        _tableView.backgroundColor = [UIColor whiteColor];
        [_tableView registerClass:ZegoSetTableViewCell.class forCellReuseIdentifier:NSStringFromClass(ZegoSetTableViewCell.class)];
        _tableView.tableFooterView = [UIView new];
    }
    return _tableView;
}

- (NSArray<NSString *> *)dataSource {
    if (!_dataSource) {
        _dataSource = @[@"源语言", @"目标语言", @"实时语音识别服务商", @"语音识别文本翻译服务商", @"语音识别文本翻译", @"文本翻译中间结果"];
    }
    return _dataSource;
}

@end
