//
//  ZegoRoleSelectCustomView.m
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/12/6.
//

#import "ZegoRoleSelectCustomView.h"
#import <Masonry/Masonry.h>
#import "UIButton+ImagePosition.h"
#import "ZegoGlobalDefines.h"
#import "ZegoItemSelectView.h"

@interface ZegoRoleSelectCustomView ()
@property (nonatomic, strong) UIButton *enterBtn;
@property (nonatomic, assign) NSInteger role;  // 角色
@property (nonatomic, strong) ZegoItemSelectView *roleItemSelectView;
@property (nonatomic, strong) ZegoItemSelectView *nickItemSelectView;
@end

@implementation ZegoRoleSelectCustomView
#pragma mark - Property
- (ZegoItemSelectView *)roleItemSelectView {
    if (!_roleItemSelectView) {
        _roleItemSelectView = [[ZegoItemSelectView alloc] init];
        _roleItemSelectView.title = @"角色";
        _roleItemSelectView.content = @"主播";
        _roleItemSelectView.showPull = YES;
        __weak typeof(self) weakSelf = self;
        _roleItemSelectView.itemSelectedBlock = ^{
            if (weakSelf.selectRoleBlock) {
                weakSelf.selectRoleBlock();
            }
        };
    }
    return _roleItemSelectView;
}

- (ZegoItemSelectView *)nickItemSelectView {
    if (!_nickItemSelectView) {
        _nickItemSelectView = [[ZegoItemSelectView alloc] init];
        _nickItemSelectView.title = @"用户昵称";
        _nickItemSelectView.showPull = NO;
        _nickItemSelectView.userName = self.username;
    }
    return _nickItemSelectView;
}

- (UIButton *)enterBtn {
    if (!_enterBtn) {
        _enterBtn = [[UIButton alloc] init];
        [_enterBtn setTitle:@"进入房间" forState:UIControlStateNormal];
        [_enterBtn setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
        _enterBtn.backgroundColor = LCColor(0, 85, 255);
        _enterBtn.titleLabel.font = [UIFont systemFontOfSize:16];
        _enterBtn.layer.cornerRadius = 5.0f;
        _enterBtn.clipsToBounds = YES;
        [_enterBtn addTarget:self action:@selector(enterBtnClicked:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _enterBtn;
}

#pragma mark - LifeCycle
- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        [self addSubview:self.enterBtn];
        [self addSubview:self.roleItemSelectView];
        [self addSubview:self.nickItemSelectView];
        
        [self.roleItemSelectView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(20);
            make.right.mas_equalTo(-30);
            make.top.mas_equalTo(45);
            make.height.mas_equalTo(35);
        }];
        
        [self.nickItemSelectView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(20);
            make.right.mas_equalTo(-30);
            make.top.equalTo(self.roleItemSelectView.mas_bottom).offset(20);
            make.height.mas_equalTo(35);
        }];
                
        [self.enterBtn mas_makeConstraints:^(MASConstraintMaker *make) {
            make.bottom.mas_equalTo(-20);
            make.height.mas_equalTo(40);
            make.width.mas_equalTo(120);
            make.centerX.mas_equalTo(0);
        }];
    }
    return self;
}

- (void)setUsername:(NSString *)username {
    _username = username;
    
    self.nickItemSelectView.userName = username;
}

- (void)setRoleName:(NSString *)roleName {
    _roleName = roleName;
    
    self.roleItemSelectView.content = roleName;
}

#pragma mark - Action
- (void)enterBtnClicked:(UIButton *)sender {
    if (self.enterRoomBlock) {
        self.enterRoomBlock(self.nickItemSelectView.nameTextField.text);
    }
}




/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/

@end
