//
//  ZegoTabChangeView.m
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/11/5.
//

#import "ZegoTabChangeView.h"
#import "ZegoGlobalDefines.h"
#import <Masonry/Masonry.h>

@interface ZegoTabChangeView ()
@property (nonatomic, strong) UIButton *realtimeTanslateBtn;
@property (nonatomic, strong) UIButton *textTranslateBtn;
@property (nonatomic, strong) UIView *lineView;
@end

@implementation ZegoTabChangeView
#pragma mark - Property
- (UIButton *)realtimeTanslateBtn {
    if (!_realtimeTanslateBtn) {
        _realtimeTanslateBtn = [[UIButton alloc] init];
        [_realtimeTanslateBtn setTitle:@"实时转译" forState:UIControlStateNormal];
        [_realtimeTanslateBtn setTitleColor:LCColor(51, 51, 51) forState:UIControlStateNormal];
        [_realtimeTanslateBtn setTitleColor:[UIColor blackColor] forState:UIControlStateSelected];
        _realtimeTanslateBtn.titleLabel.font = [UIFont systemFontOfSize:18 weight:UIFontWeightBold];
        _realtimeTanslateBtn.selected = YES;
        [_realtimeTanslateBtn addTarget:self action:@selector(realtimeTanslateBtnClicked:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _realtimeTanslateBtn;
}

- (UIButton *)textTranslateBtn {
    if (!_textTranslateBtn) {
        _textTranslateBtn = [[UIButton alloc] init];
        [_textTranslateBtn setTitle:@"文本翻译" forState:UIControlStateNormal];
        [_textTranslateBtn setTitleColor:LCColor(102, 102, 102) forState:UIControlStateNormal];
        [_textTranslateBtn setTitleColor:[UIColor blackColor] forState:UIControlStateSelected];
        _textTranslateBtn.titleLabel.font = [UIFont systemFontOfSize:18 weight:UIFontWeightRegular];
        _textTranslateBtn.selected = NO;
        [_textTranslateBtn addTarget:self action:@selector(textTranslateBtnClicked:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _textTranslateBtn;
}

- (UIView *)lineView {
    if (!_lineView) {
        _lineView = [[UIView alloc] init];
        _lineView.backgroundColor = [UIColor blackColor];
    }
    return _lineView;
}

#pragma mark - LifeCycle
- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        [self addSubview:self.realtimeTanslateBtn];
        [self addSubview:self.textTranslateBtn];
        [self addSubview:self.lineView];
        
        [self.realtimeTanslateBtn mas_makeConstraints:^(MASConstraintMaker *make) {
            make.top.mas_equalTo(0);
            make.left.mas_equalTo(0);
            make.width.mas_equalTo(80);
            make.height.mas_equalTo(22);
        }];
        
        [self.textTranslateBtn mas_makeConstraints:^(MASConstraintMaker *make) {
            make.top.equalTo(self.realtimeTanslateBtn.mas_top);
            make.left.equalTo(self.realtimeTanslateBtn.mas_right).offset(20);
            make.width.mas_equalTo(80);
            make.height.mas_equalTo(22);
        }];
        
        [self.lineView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.centerX.equalTo(self.realtimeTanslateBtn);
            make.width.mas_equalTo(75);
            make.height.mas_equalTo(1.0);
            make.top.equalTo(self.realtimeTanslateBtn.mas_bottom);
        }];
    }
    return self;
}

#pragma mark - Action
- (void)realtimeTanslateBtnClicked:(UIButton *)sender {
    sender.selected = YES;
    self.textTranslateBtn.selected = NO;
    self.realtimeTanslateBtn.titleLabel.font = [UIFont systemFontOfSize:18.0 weight:UIFontWeightBold];
    self.textTranslateBtn.titleLabel.font = [UIFont systemFontOfSize:18.0 weight:UIFontWeightRegular];
    [self.lineView mas_remakeConstraints:^(MASConstraintMaker *make) {
        make.centerX.equalTo(self.realtimeTanslateBtn);
        make.width.mas_equalTo(75);
        make.height.mas_equalTo(1.0);
        make.top.equalTo(self.realtimeTanslateBtn.mas_bottom);
    }];
    
    if (self.tabChangedBlock) {
        self.tabChangedBlock(YES);
    }
}

- (void)textTranslateBtnClicked:(UIButton *)sender {
    sender.selected = YES;
    self.realtimeTanslateBtn.selected = NO;
    self.textTranslateBtn.titleLabel.font = [UIFont systemFontOfSize:18.0 weight:UIFontWeightBold];
    self.realtimeTanslateBtn.titleLabel.font = [UIFont systemFontOfSize:18.0 weight:UIFontWeightRegular];
    
    [self.lineView mas_remakeConstraints:^(MASConstraintMaker *make) {
        make.centerX.equalTo(self.textTranslateBtn);
        make.width.mas_equalTo(75);
        make.height.mas_equalTo(1.0);
        make.top.equalTo(self.textTranslateBtn.mas_bottom);
    }];
    
    if (self.tabChangedBlock) {
        self.tabChangedBlock(NO);
    }
}


@end
