//
//  ZegoTextTranslateView.m
//  ZegoVoiceTranslation
//
//  Created by zego on 2022/11/5.
//

#import "ZegoTextTranslateView.h"
#import "ZegoGlobalDefines.h"
#import <Masonry/Masonry.h>
#import "ZegoSetTableViewCell.h"
#import "ZegoLanguageSupport.h"

@interface ZegoTextTranslateView ()<UITableViewDelegate, UITableViewDataSource, UITextViewDelegate>
@property (nonatomic, strong) UITextView *inputTextView;
@property (nonatomic, strong) UITextView *outputTextView;
@property (nonatomic, strong) UILabel *inputPlaceholderLab;
@property (nonatomic, strong) UILabel *outputPlaceholderLab;
@property (nonatomic, strong) UIButton *clearBtn;
@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, strong) UIButton *startTranslateBtn;
@property (nonatomic, strong) UILabel *setLab;
@property (nonatomic, strong) NSArray<NSString *> *dataSource;
@property (nonatomic, strong) UILabel *elapseLabel; // 耗时时间显示
@property (nonatomic, strong) NSMutableDictionary<NSString *, ZegoTransLanguageModel *> *transLanguagesDict;

@end

@implementation ZegoTextTranslateView
static int MAX_CHAR_LIMIT = 1000;

#pragma mark - LifeCycle
- (instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self) {
        [self addSubview:self.inputTextView];
        [self addSubview:self.outputTextView];
        [self addSubview:self.inputPlaceholderLab];
        [self addSubview:self.outputPlaceholderLab];
        [self addSubview:self.elapseLabel];
        [self addSubview:self.clearBtn];
        [self addSubview:self.setLab];
        [self addSubview:self.startTranslateBtn];
        [self addSubview:self.tableView];
        
        [self.inputTextView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(10);
            make.right.mas_equalTo(-10);
            make.top.mas_equalTo(0);
            make.height.mas_equalTo(80);
        }];
        
        [self.outputTextView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.top.equalTo(self.inputTextView.mas_bottom).offset(2);
            make.left.mas_equalTo(10);
            make.right.mas_equalTo(-10);
            make.height.mas_equalTo(80);
        }];
        
        [self.inputPlaceholderLab mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.equalTo(self.inputTextView.mas_left).offset(5);
            make.right.equalTo(self.inputTextView.mas_right).offset(-5);
            make.top.equalTo(self.inputTextView.mas_top).offset(7);
        }];
        
        [self.outputPlaceholderLab mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.equalTo(self.outputTextView.mas_left).offset(5);
            make.top.equalTo(self.outputTextView.mas_top).offset(7);
        }];
        
        [self.elapseLabel mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.equalTo(self.outputTextView.mas_left).offset(0);
            make.top.equalTo(self.outputTextView.mas_bottom).offset(3);
            make.height.mas_equalTo(15);
        }];
        
        [self.clearBtn mas_makeConstraints:^(MASConstraintMaker *make) {
            make.right.mas_equalTo(-20);
            make.width.mas_equalTo(70);
            make.height.mas_equalTo(30);
            make.top.equalTo(self.outputTextView.mas_bottom).offset(10);
        }];
        
        [self.setLab mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(10);
            make.top.equalTo(self.clearBtn.mas_bottom);
        }];
        
        [self.startTranslateBtn mas_makeConstraints:^(MASConstraintMaker *make) {
            make.width.mas_equalTo(180);
            make.height.mas_equalTo(40);
            make.bottom.mas_equalTo(-20);
            make.centerX.mas_equalTo(0);
        }];
        
        [self.tableView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.right.mas_equalTo(0);
            make.bottom.equalTo(self.startTranslateBtn.mas_top);
            make.top.equalTo(self.setLab.mas_bottom).offset(0);
        }];
    }
    return self;
}

#pragma mark - Action
- (void)clearBtnClicked:(UIButton *)sender {
    self.inputTextView.text = @"";
    self.outputTextView.text = @"";
    self.inputPlaceholderLab.hidden = NO;
    self.outputPlaceholderLab.hidden = NO;
}

- (void)startTranslateBtnClicked:(UIButton *)sender {
    NSString *translateText = [self.inputTextView.text stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceCharacterSet]];
    if (self.startTranslateBlock) {
        self.startTranslateBlock(translateText);
    }
}

#pragma mark - Set
- (void)setSourceLanguage:(ZegoTranslationLanguage)sourceLanguage {
    _sourceLanguage = sourceLanguage;
    [self.tableView reloadData];
}

- (void)setTargetLanguage:(ZegoTranslationLanguage)targetLanguage {
    _targetLanguage = targetLanguage;
    [self.tableView reloadData];
}

- (void)setTranslateProvider:(ZegoRTServiceProvider)translateProvider {
    _translateProvider = translateProvider;
    
    if (translateProvider == ZegoRTServiceProviderGoogle) {
        self.transLanguages = [ZegoLanguageSupport getGoogleTransLanguages];
    } else if (translateProvider == ZegoRTServiceProviderIflytek) {
        self.transLanguages = [ZegoLanguageSupport getIflyTransLanguages];
    } else if (translateProvider == ZegoRTServiceProviderLiveData) {
        self.transLanguages = [ZegoLanguageSupport getLiveDataTransLanguages];
    }
    
    [self.transLanguagesDict removeAllObjects];
    for (ZegoTransLanguageModel *model in self.transLanguages) {
        [self.transLanguagesDict setObject:model forKey:@(model.language).stringValue];
    }
    
    if (![self.transLanguagesDict.allKeys containsObject:@(self.sourceLanguage).stringValue]) {
        self.sourceLanguage = ZegoTranslationLanguageZH_HANS;
    }
    
    if (![self.transLanguagesDict.allKeys containsObject:@(self.targetLanguage).stringValue]) {
        self.targetLanguage = ZegoTranslationLanguageEN;
    }
    
    [self.tableView reloadData];
}

- (void)setTranslateText:(NSString *)translateText {
    _translateText = translateText;
    self.outputPlaceholderLab.hidden = translateText.length > 0;
    self.outputTextView.text = translateText;
}

- (void)setElapseTime:(NSString *)elapseTime {
    _elapseTime = elapseTime;
    
    self.elapseLabel.text = elapseTime;
}

#pragma mark - UITableViewDelegate & UITableViewDataSource
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.dataSource.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    ZegoSetTableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"ZegoTextTranslateSetCell"];
    cell.titleLab.text = self.dataSource[indexPath.row];
    cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
    cell.sw.hidden = YES;
    switch (indexPath.row) {
        case 0:
        {
            ZegoTransLanguageModel *model = [self.transLanguagesDict objectForKey:@(self.sourceLanguage).stringValue];
            cell.contentLab.text = model.language_name;
        }
            break;
        case 1:
        {
            ZegoTransLanguageModel *model = [self.transLanguagesDict objectForKey:@(self.targetLanguage).stringValue];
            cell.contentLab.text = model.language_name;
        }
            break;
        case 2:
            cell.contentLab.text = [[ZegoSdkConfig config] getThirdServiceProviderName:self.translateProvider];
            break;
        default:
            break;
    }
    cell.selectionStyle = UITableViewCellSelectionStyleNone;
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    if (self.textTranslateSetItemBlock) {
        self.textTranslateSetItemBlock(indexPath.row);
    }
}

#pragma mark - UITextViewDelegate
- (void)textViewDidChange:(UITextView *)textView {
    self.inputPlaceholderLab.hidden = textView.text.length > 0;
    
    NSString *content = textView.text;
    if (content.length > MAX_CHAR_LIMIT) {
        self.inputTextView.text = [content substringToIndex:MAX_CHAR_LIMIT];
    }
}

#pragma mark - Private
- (UITextView *)makeupShowTextView {
    UITextView *textView = [[UITextView alloc] init];
    textView.textColor = LCColor(51, 51, 51);
    textView.font = [UIFont systemFontOfSize:13];
    textView.layer.cornerRadius = 2.0f;
    textView.clipsToBounds = YES;
    textView.layer.borderColor = LCColor(51, 51, 51).CGColor;
    textView.layer.borderWidth = 1.0f;
    return textView;
}

#pragma mark - Property
- (NSArray<ZegoTransLanguageModel *> *)transLanguages {
    if (!_transLanguages) {
        _transLanguages = [NSArray array];
    }
    return _transLanguages;
}

- (NSMutableDictionary<NSString *,ZegoTransLanguageModel *> *)transLanguagesDict {
    if (!_transLanguagesDict) {
        _transLanguagesDict = [NSMutableDictionary dictionary];
    }
    return _transLanguagesDict;
}

- (UITextView *)inputTextView {
    if (!_inputTextView) {
        _inputTextView = [self makeupShowTextView];
        _inputTextView.editable = YES;
        _inputTextView.delegate = self;
    }
    return _inputTextView;
}

- (UITextView *)outputTextView {
    if (!_outputTextView) {
        _outputTextView = [self makeupShowTextView];
        _outputTextView.editable = NO;
    }
    return _outputTextView;
}

- (UILabel *)inputPlaceholderLab {
    if (!_inputPlaceholderLab) {
        _inputPlaceholderLab = [[UILabel alloc] init];
        _inputPlaceholderLab.text = @"请输入需要翻译的文本，体验前先设置语言(限制 1000 字符)";
        _inputPlaceholderLab.font = [UIFont systemFontOfSize:13];
        _inputPlaceholderLab.textColor = LCColor(153, 153, 153);
        _inputPlaceholderLab.numberOfLines = 0;
    }
    return _inputPlaceholderLab;
}

- (UILabel *)outputPlaceholderLab {
    if (!_outputPlaceholderLab) {
        _outputPlaceholderLab = [[UILabel alloc] init];
        _outputPlaceholderLab.text = @"文本翻译结果";
        _outputPlaceholderLab.font = [UIFont systemFontOfSize:13];
        _outputPlaceholderLab.textColor = LCColor(153, 153, 153);
    }
    return _outputPlaceholderLab;
}

- (UILabel *)elapseLabel {
    if (!_elapseLabel) {
        _elapseLabel = [[UILabel alloc] init];
        _elapseLabel.text = @"";
        _elapseLabel.font = [UIFont systemFontOfSize:13];
        _elapseLabel.textColor = LCColor(102, 102, 102);
    }
    return _elapseLabel;
}

- (UIButton *)clearBtn {
    if (!_clearBtn) {
        _clearBtn = [[UIButton alloc] init];
        [_clearBtn setTitle:@"清屏" forState:UIControlStateNormal];
        [_clearBtn setTitleColor:LCColor(51, 51, 51) forState:UIControlStateNormal];
        _clearBtn.titleLabel.font = [UIFont systemFontOfSize:13];
        _clearBtn.layer.cornerRadius = 4.0f;
        _clearBtn.clipsToBounds = YES;
        _clearBtn.layer.borderColor = LCColor(51, 51, 51).CGColor;
        _clearBtn.layer.borderWidth = 1.0f;
        [_clearBtn addTarget:self action:@selector(clearBtnClicked:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _clearBtn;
}

- (UILabel *)setLab {
    if (!_setLab) {
        _setLab = [[UILabel alloc] init];
        _setLab.text = @"设置";
        _setLab.font = [UIFont systemFontOfSize:18 weight:UIFontWeightBold];
        _setLab.textColor = [UIColor blackColor];
    }
    return _setLab;
}

- (UIButton *)startTranslateBtn {
    if (!_startTranslateBtn) {
        _startTranslateBtn = [[UIButton alloc] init];
        [_startTranslateBtn setTitle:@"开启文本翻译" forState:UIControlStateNormal];
        [_startTranslateBtn setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
        _startTranslateBtn.backgroundColor = [UIColor blueColor];
        _startTranslateBtn.titleLabel.font = [UIFont systemFontOfSize:15];
        _startTranslateBtn.layer.cornerRadius = 4.0f;
        _startTranslateBtn.clipsToBounds = YES;
        [_startTranslateBtn addTarget:self action:@selector(startTranslateBtnClicked:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _startTranslateBtn;
}

- (UITableView *)tableView {
    if (!_tableView) {
        _tableView = [[UITableView alloc] initWithFrame:CGRectZero style:UITableViewStylePlain];
        _tableView.delegate = self;
        _tableView.dataSource = self;
        _tableView.rowHeight = 44.0;
        _tableView.backgroundColor = [UIColor whiteColor];
        [_tableView registerClass:ZegoSetTableViewCell.class forCellReuseIdentifier:@"ZegoTextTranslateSetCell"];
        _tableView.tableFooterView = [UIView new];
    }
    return _tableView;
}

- (NSArray<NSString *> *)dataSource {
    if (!_dataSource) {
        _dataSource = @[@"源语言", @"目标语言", @"文本翻译服务商"];
    }
    return _dataSource;
}

@end
